@@ -50,6 +50,8 @@ BEGIN_MESSAGE_MAP(CAccountView, CFormView)
 	//{{AFX_MSG_MAP(CAccountView)
 	ON_WM_SIZE()
 	ON_CBN_SELCHANGE(IDC_COMBO_ACCOUNT, OnSelchangeAccount)
+	ON_COMMAND(ID_NEXT_ACCOUNT, OnNextAccount)
+	ON_COMMAND(ID_PREV_ACCOUNT, OnPrevAccount)
 	//}}AFX_MSG_MAP
 END_MESSAGE_MAP()
 
@@ -182,11 +184,12 @@ void CAccountView::OnSelchangeAccount()
 	mf->SetStatusBarProgress(m_data[GetAccountNum(account)].status_pgbar_current, m_data[GetAccountNum(account)].status_pgbar_upper);
 	mf->SetStatusBarText(0, m_data[GetAccountNum(account)].status_text);
 
-	// replyAtransferAheaderAgpg button at toolbar is invalidated.
-	mf->m_button_reply = FALSE;
+	// replyAtransferAheader at toolbar is invalidated.
+/*	mf->m_button_reply = FALSE;
 	mf->m_button_transfer = FALSE;
 	mf->m_button_info = FALSE;
-	mf->m_button_gpg_dec = FALSE;
+	mf->m_button_gpg_dec = FALSE;*/
+	mf->UpdateButton2(FALSE);
 
 	// if multipartview is showing, hide.
 	sv->Clear();
@@ -208,17 +211,6 @@ BOOL CAccountView::PreCreateWindow(CREATESTRUCT& cs)
 	return CFormView::PreCreateWindow(cs);
 }
 
-BOOL CAccountView::PreTranslateMessage(MSG* pMsg)
-{
-	CPochyApp* app = (CPochyApp*)AfxGetApp();
-	CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;
-	if(pMsg->message == WM_CHAR){
-		if(mf->Char(pMsg->wParam))
-			return TRUE;
-	}
-	return CFormView::PreTranslateMessage(pMsg);
-}
-
 void CAccountView::RenameAccount(const char *org, const char *dst)
 {
 //	CPochyApp* app = (CPochyApp*)AfxGetApp();
@@ -238,8 +230,7 @@ void CAccountView::RenameAccount(const char *org, const char *dst)
 	as.is_fetching = FALSE;
 	m_data.Add(as);
 
-	m_combo_account.SetCurSel(index);
-	OnSelchangeAccount();
+	SelectAccount(index);
 }
 
 void CAccountView::CreateNewAccount(const char *name)
@@ -432,8 +423,63 @@ CString CAccountView::GetAccountPopPass(CString account)
 	return m_data[index].pop_pass;
 }
 
+CString CAccountView::GetSmtpAuthPass(CString account)
+{
+	int index = GetAccountNum(account);
+	return m_data[index].smtp_auth_pass;
+}
+
 void CAccountView::SetAccountPopPass(CString account, CString pass)
 {
 	int index = GetAccountNum(account);
 	m_data[index].pop_pass = pass;
 }
+
+void CAccountView::SetSmtpAuthPass(CString account, CString pass)
+{
+	int index = GetAccountNum(account);
+	m_data[index].smtp_auth_pass = pass;
+}
+
+void CAccountView::OnNextAccount()
+{
+	int nAccountCount = m_combo_account.GetCount();
+	int nCurSel = m_combo_account.GetCurSel();
+	int nSelect = 0;
+
+	if (nCurSel < nAccountCount - 1)
+	{
+		nSelect = nCurSel + 1;
+	}
+
+	if (nSelect != nCurSel)
+	{
+		SelectAccount(nSelect);
+	}
+}
+
+void CAccountView::OnPrevAccount()
+{
+	int nAccountCount = m_combo_account.GetCount();
+	int nCurSel = m_combo_account.GetCurSel();
+	int nSelect = nAccountCount - 1;
+
+	if (nCurSel > 0)
+	{
+		nSelect = nCurSel - 1;
+	}
+
+	if (nSelect != nCurSel)
+	{
+		SelectAccount(nSelect);
+	}
+}
+
+void CAccountView::SelectAccount(const int &nIndex)
+{
+	if (0 <= nIndex && nIndex < m_combo_account.GetCount())
+	{
+		m_combo_account.SetCurSel(nIndex);
+		OnSelchangeAccount();
+	}
+}
