@@ -55,6 +55,7 @@ BEGIN_MESSAGE_MAP(CAddressView, CFormView)
 	ON_BN_CLICKED(IDC_BUTTON_TO, OnTo)
 	ON_BN_CLICKED(IDC_BUTTON_CC, OnCc)
 	ON_BN_CLICKED(IDC_BUTTON_BCC, OnBcc)
+	ON_COMMAND(ID_ADDRESS_COMPLEMENT, Complete)
 	//}}AFX_MSG_MAP
 END_MESSAGE_MAP()
 
@@ -262,6 +263,7 @@ BOOL CAddressView::PreTranslateMessage(MSG* pMsg)
 			}
 		}
 	}
+
 	return CFormView::PreTranslateMessage(pMsg);
 }
 
@@ -285,9 +287,10 @@ void CAddressView::Complete()
 	int n;
 	CString piece;
 	CString address;
+	int nLength = buf.GetLength();
 	if((n = buf.ReverseFind(',')) != -1){
 		n++;
-		while(buf[n] == ' ' || buf[n] == '\t')  /* 󔒂ǂݔ΂ */
+		while(n < nLength && (buf[n] == ' ' || buf[n] == '\t'))  /* 󔒂ǂݔ΂ */
 			++n;
 		CString left = buf.Left(n);
 		CString right = buf.Mid(n);
