@@ -16,10 +16,7 @@
 #include "lib.h"
 #include "sendmail.h"
 #include "direct.h"			// _mkdir
-// modified by hiranaka, Pochy0.1.9, 2003/11/23
-// start
 #include "skin.h"
-// end
 
 #ifdef _DEBUG
 #define new DEBUG_NEW
@@ -27,10 +24,7 @@
 static char THIS_FILE[] = __FILE__;
 #endif
 
-// modified by hiranaka, Pochy0.1.9, 2003/11/23
-// start
 #define ATTACHEDFILEVIEW_BACKGROUND_FILENAME _T("\\skin\\AttachedFileViewBk.bmp")
-// end
 
 /////////////////////////////////////////////////////////////////////////////
 // CAttachedFileView
@@ -146,7 +140,7 @@ void CAttachedFileView::OnInitialUpdate()
 				int len = from64tobits(out, in, strlen(in));
 				fwrite(out, sizeof(char), len, file);
 				fclose(file);
-				delete out;
+				delete[] out;
 				body.ReleaseBuffer();
 
 				// add item
@@ -155,8 +149,6 @@ void CAttachedFileView::OnInitialUpdate()
 			}
 		}
 	}
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
 	// skin.ini
 	CString strBackgroundFilePath;
 	if(app->m_skin.getAttachedFileViewBackBmp() == ""){
@@ -165,7 +157,6 @@ void CAttachedFileView::OnInitialUpdate()
 		strBackgroundFilePath = app->m_skin.getSkinIniPath() + "\\" + app->m_skin.getAttachedFileViewBackBmp();
 	}
 	SetBkImage(strBackgroundFilePath);
-// end
 }
 
 void CAttachedFileView::OnRclick(NMHDR* pNMHDR, LRESULT* pResult)
@@ -234,7 +225,7 @@ void CAttachedFileView::ExecuteFile()
 		int len = from64tobits(out, in, strlen(in));
 		fwrite(out, sizeof(char), len, file);
 		fclose(file);
-		delete out;
+		delete[] out;
 		body.ReleaseBuffer();
 	}
 	ShellExecute(NULL, "open", app->m_app_path+"\\temp\\"+df->m_me.GetMultipartFileName(m_index+1), NULL, NULL, SW_SHOW);
