@@ -272,7 +272,7 @@ LPCTSTR CCodeConvert::JisToSjis()
 	*out_buf_p = '\0';
 	iconv_close(cd);
 	message = start;
-	delete out_buf_p;
+	delete[] out_buf_p;
 
 	return message.GetBuffer(0);*/
 
