@@ -74,6 +74,7 @@ BEGIN_MESSAGE_MAP(CDraftFrame, CFrameWnd)
 	ON_WM_SIZE()
 	ON_UPDATE_COMMAND_UI(ID_SEND_MAIL, OnUpdateSend)
 	ON_UPDATE_COMMAND_UI(ID_DRAFT_GPG, OnUpdateGpg)
+	ON_UPDATE_COMMAND_UI(ID_GPG_DRAFT_KEY_MANAGEMENT, OnUpdateGpg)
 	ON_UPDATE_COMMAND_UI(ID_GPG_ENC, OnUpdateGpgEnc)
 	ON_UPDATE_COMMAND_UI(ID_GPG_EXP, OnUpdateGpgExp)
 	ON_UPDATE_COMMAND_UI(ID_ADD_FILE, OnUpdateAddFile)
@@ -94,6 +95,7 @@ BEGIN_MESSAGE_MAP(CDraftFrame, CFrameWnd)
 	ON_WM_CHAR()
 	ON_UPDATE_COMMAND_UI(ID_DRAFT_GPG, OnUpdateGpg)
 	ON_WM_KEYDOWN()
+	ON_COMMAND(ID_SWITCH_VIEW, OnSwitchView)
 	//}}AFX_MSG_MAP
 	ON_COMMAND(WM_END, OnEnd)
 	ON_COMMAND(WM_PROGCREATE, OnProgCreate)
@@ -162,6 +164,8 @@ int CDraftFrame::OnCreate(LPCREATESTRUCT lpCreateStruct)
 		this->MoveWindow(rc);
 	}
 
+	m_pAddrsV->SetFocus();
+
 	return 0;
 }
 
@@ -362,7 +366,6 @@ void CDraftFrame::RecoverIME(CView* view)
 
 BOOL CDraftFrame::KeyDown(UINT nChar,CView* view)
 {
-//	CPochyApp* app = (CPochyApp*)AfxGetApp();
 	CStatusBar& sb = this->m_wndStatusBar;
 	if(::GetKeyState(VK_CONTROL) & 0xff00){	// whether or not pressing CTRL
 		switch(nChar){
@@ -408,7 +411,7 @@ BOOL CDraftFrame::Char(UINT nChar,CView* view)
 		case 'o':
 			this->m_wndStatusBar.SetPaneText(0,"C-x o");
 			this->RecoverIME(view);
-			this->SwitchView();
+			this->OnSwitchView();
 			this->m_wndStatusBar.SetPaneText(0,"");
 			return TRUE;
 		case 19:
@@ -466,7 +469,7 @@ void CDraftFrame::OnUpdateExtEditor(CCmdUI* pCmdUI)
 	pCmdUI->Enable(m_button_exteditor);
 }
 
-void CDraftFrame::SwitchView()
+void CDraftFrame::OnSwitchView()
 {
 	CWnd* wnd = GetFocus();
 	if(wnd == m_pEditV)
@@ -677,10 +680,7 @@ BOOL CDraftFrame::SaveToDraft(BOOL confirm)
 	CMainFrame *mf = (CMainFrame *)app->m_pMainWnd;
 	CSummaryView *sv = mf->m_pListV;
 	CString path = app->m_app_path+"\\"+m_account+"\\draft";
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
 	CString box_name;
-// end
 
 	CString body;
 	m_pEditV->GetText(body);
@@ -701,9 +701,7 @@ BOOL CDraftFrame::SaveToDraft(BOOL confirm)
 	// need or not confirmation dialog.
 	if(confirm){
 		CString message;
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
-//		message.Format("%s\r\n\r\ndraft֕ۑ܂H", m_me.GetSubject());
+
 		GetPrivateProfileString(
 			"mailbox",
 			"draft",
@@ -717,7 +715,6 @@ BOOL CDraftFrame::SaveToDraft(BOOL confirm)
 		}else{
 			message.Format("%s\r\n\r\n%s֕ۑ܂H", m_me.GetSubject(), box_name);
 		}
-// end
 		int check = this->MessageBox(message, "[̕ۑ", MB_YESNOCANCEL);
 		if(check == IDYES){
 			sv->SaveMail(path, m_me.GetMail(ME_GET_DRAFT), SMRY_STATUS_NONE, SMRY_COLUMN_TO);
@@ -763,11 +760,13 @@ void CDraftFrame::OnChangeTxtColorDraft()
 
 }
 
-void CDraftFrame::OnToolbarDropDown(NMTOOLBAR* pnmtb, LRESULT *plr)
+BOOL CDraftFrame::OnToolbarDropDown(NMHDR *pNMHDR, LRESULT *plr)
 {
 	CWnd *pWnd;
 	UINT nID;
 
+	NMTOOLBAR *pnmtb = (NMTOOLBAR *)pNMHDR;
+
 	// Switch on button command id's
 	switch (pnmtb->iItem){
 	case ID_DRAFT_GPG:
@@ -775,7 +774,7 @@ void CDraftFrame::OnToolbarDropDown(NMTOOLBAR* pnmtb, LRESULT *plr)
 		nID  = IDR_DRAFTFRAME_POPUP_GPG;
 		break;
 	default:
-		return;
+		return TRUE;
 	}
 
 	// load and display popup menu
@@ -789,6 +788,8 @@ void CDraftFrame::OnToolbarDropDown(NMTOOLBAR* pnmtb, LRESULT *plr)
 	pWnd->ClientToScreen(&rc);
 
 	pPopup->TrackPopupMenu( TPM_LEFTALIGN | TPM_LEFTBUTTON | TPM_VERTICAL, rc.left, rc.bottom, this, &rc);
+
+	return TRUE;
 }
 
 BOOL CDraftFrame::PreCreateWindow(CREATESTRUCT& cs) 
@@ -893,3 +894,72 @@ void CDraftFrame::OnKeyDown(UINT nChar, UINT nRepCnt, UINT nFlags)
 	}
 	CFrameWnd::OnKeyDown(nChar, nRepCnt, nFlags);
 }
+
+BOOL CDraftFrame::PreTranslateMessage(MSG* pMsg) 
+{
+	if (m_acceleratorTable.TranslateAccelerator(m_hWnd, pMsg))
+	{
+		return TRUE;
+	}
+	
+	return CFrameWnd::PreTranslateMessage(pMsg);
+}
+
+BOOL CDraftFrame::OnCommand(WPARAM wParam, LPARAM lParam) 
+{
+	switch (LOWORD(wParam))
+	{
+	case ID_ADDRESS_COMPLEMENT:
+		{
+			// Address View ̃CxgđM
+			return ::SendMessage(m_pAddrsV->GetSafeHwnd(), WM_COMMAND, wParam, lParam);
+		}
+		break;
+	}
+	
+	return CFrameWnd::OnCommand(wParam, lParam);
+}
+
+void CDraftFrame::LoadAccelerator()
+{
+	CPochyApp *app = (CPochyApp*)AfxGetApp();
+	std::string strKeyIniPath = app->m_app_path + _T("\\KeySetting.ini");
+//	m_acceleratorTable.Save(strKeyIniPath, _T("DraftFrameKey"));
+	m_acceleratorTable.Load(strKeyIniPath, _T("DraftFrameKey"));
+	HMENU hMenu = ::GetMenu(m_hWnd);
+	m_acceleratorTable.ModifyMenuCaption(hMenu);
+}
+
+void CDraftFrame::SetAcceleratorTargetWindow()
+{
+	m_acceleratorTable.AddTargetWindow(m_pEditV->GetSafeHwnd());
+	m_acceleratorTable.AddTargetWindow(m_pAddrsV->m_to.GetSafeHwnd());
+	m_acceleratorTable.AddTargetWindow(m_pAddrsV->m_cc.GetSafeHwnd());
+	m_acceleratorTable.AddTargetWindow(m_pAddrsV->m_bcc.GetSafeHwnd());
+	m_acceleratorTable.AddTargetWindow(m_pAddrsV->m_subject.GetSafeHwnd());
+	m_acceleratorTable.AddTargetWindow(m_pAddrsV->m_reply_to.GetSafeHwnd());
+	m_acceleratorTable.AddTargetWindow(m_pAddrsV->m_from.GetSafeHwnd());
+	m_acceleratorTable.AddTargetWindow(m_pAddrsV->GetDlgItem(IDC_BUTTON_TO)->GetSafeHwnd());
+	m_acceleratorTable.AddTargetWindow(m_pAddrsV->GetDlgItem(IDC_BUTTON_CC)->GetSafeHwnd());
+	m_acceleratorTable.AddTargetWindow(m_pAddrsV->GetDlgItem(IDC_BUTTON_BCC)->GetSafeHwnd());
+	m_acceleratorTable.AddTargetWindow(m_pListV2->GetSafeHwnd());
+}
+
+void CDraftFrame::LoadDefaultAccelerator()
+{
+	m_acceleratorTable.DeleteAll();
+
+	m_acceleratorTable.AddAccelerator(_T("SendMail"),			ID_SEND_MAIL,					_T("Ctrl+T"),		_T("M(&T)"));
+	m_acceleratorTable.AddAccelerator(_T("SwitchView"),			ID_SWITCH_VIEW,					_T("Ctrl+O"),		_T("r[̃tH[JX؂ւ"));
+	m_acceleratorTable.AddAccelerator(_T("SaveToDraft"),		ID_SAVE_TO_DRAFT,				_T("Ctrl+S"),		_T("htg֕ۑ(&S)"));
+	m_acceleratorTable.AddAccelerator(_T("AddFile"),			ID_ADD_FILE,					_T("Ctrl+I"),		_T("Yt(&I)..."));
+	m_acceleratorTable.AddAccelerator(_T("ExternalEditor"),		ID_DRAFT_EXT_EDITOR,			_T("Ctrl+E"),		_T("OGfB^[(&E)..."));
+	m_acceleratorTable.AddAccelerator(_T("ShowAddressBook"),	ID_DRAFT_ADDRESS,				_T("Ctrl+B"),		_T("AhX\(&A)..."));
+	m_acceleratorTable.AddAccelerator(_T("GPGKeyManagement"),	ID_GPG_DRAFT_KEY_MANAGEMENT,	_T("Ctrl+G"),		_T("̊Ǘ(&G)..."));
+	m_acceleratorTable.AddAccelerator(_T("GPGEncode"),			ID_GPG_ENC,						_T("Ctrl+K"),		_T("Í(&K)"));
+	m_acceleratorTable.AddAccelerator(_T("GPGAttachKey"),		ID_GPG_EXP,						_T(""),				_T("̓Yt(&E)"));
+	m_acceleratorTable.AddAccelerator(_T("AddressComplement"),	ID_ADDRESS_COMPLEMENT,			_T("Ctrl+UP"),		_T("AhX̕⊮"));
+	m_acceleratorTable.AddAccelerator(_T("AddressComplement"),	ID_ADDRESS_COMPLEMENT,			_T("Ctrl+DOWN"),	_T("AhX̕⊮"));
+
+	m_acceleratorTable.CreateAcceleratorTable();
+}
