@@ -71,7 +71,7 @@ UINT FetchMail(LPVOID pParam)
 	int mail_size = 0;
 	int size;
 	int get_size = 0;
-	int start;
+	int start=0;
 	int cnt;
 	int delete_mail;
 
@@ -89,7 +89,7 @@ UINT FetchMail(LPVOID pParam)
 	CAccountView *av = mf->m_pAcntV;
 
 	// Ct[̎M{^𖳌ɂ
-	mf->UpdateButton(FALSE, account);
+	mf->UpdateButton1(FALSE, account);
 
 	// [ۑ挈̂߂̃tB^̐ݒ
 	CFilter filter(app->m_app_path+"\\"+account);
@@ -119,6 +119,17 @@ UINT FetchMail(LPVOID pParam)
 		// get password from ini file.
 		GetPrivateProfileString("pop", "pass", "", pass.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
 		pass.ReleaseBuffer();
+
+		CString isSecreted;
+		GetPrivateProfileString("secreted", "pass_secreted", "", isSecreted.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+		isSecreted.ReleaseBuffer();
+		//if pass_secreted equals "yes" then pass decode.
+		if(!isSecreted.IsEmpty()) {	
+			if(isSecreted.Compare("yes") == 0) {
+				pass = g_simple_decode(pass);
+			}
+		}
+
 		if(pass.IsEmpty() && !mf->m_pAcntV->GetAccountPopPass(account).IsEmpty())
 			pass = mf->m_pAcntV->GetAccountPopPass(account);
 		else if(pass.IsEmpty() && mf->m_pAcntV->GetAccountPopPass(account).IsEmpty()){
@@ -205,7 +216,7 @@ UINT FetchMail(LPVOID pParam)
 		buf.ReleaseBuffer();
 		buf.Empty();
 
-		start = 0;
+//		start = 0;
 
 		// .init@CO̍ŏI擾[uid擾
 		GetPrivateProfileString("pop", "last_uid", "", last_uid.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
@@ -229,13 +240,14 @@ UINT FetchMail(LPVOID pParam)
 			buf.Empty();
 			buf.ReleaseBuffer();
 			// uidlłƂėXg̉Ԗڂlast_uid邩mF
-			cnt = 0;
-			while(cnt < uidl_array.GetSize()){
+//			cnt = 0;
+//			while(cnt < uidl_array.GetSize()){
+			for(cnt=0; cnt < uidl_array.GetSize(); cnt++){
 				if(last_uid == uidl_array.GetAt(cnt)){
 					start = cnt+1;
 					break;
 				}
-				cnt++;
+//				cnt++;
 			}
 		}
 
@@ -249,12 +261,22 @@ UINT FetchMail(LPVOID pParam)
 		// decide whether or not deleting mail.
 		delete_mail = GetPrivateProfileInt("pop", "delete_mail", 0, path);
 
+		// delete already fetched mail before retr
+		if(delete_mail){
+			for(cnt=0; cnt < start; cnt++){
+				wsprintf(dele, "dele %d\r\n", cnt+1);
+				send(pop_socket.m_sock, dele , strlen(dele), 0);
+				pop_socket.SockRead(buf);
+				buf.Empty();				
+			}
+		}
+
 		// below is loop for getting mail.
-		for(int i = start; i < how_many_mail; i++){
+		for(cnt = start; cnt < how_many_mail; cnt++){
 			fetched = TRUE;
 			if(start == 0){
 				// getting uid of currently fetched mail.
-				wsprintf(uidl, "uidl %d\r\n", i+1);
+				wsprintf(uidl, "uidl %d\r\n", cnt+1);
 				send(pop_socket.m_sock, uidl, strlen(uidl), 0);
 				pop_socket.SockRead(buf);
 				buf.TrimRight();
@@ -263,19 +285,25 @@ UINT FetchMail(LPVOID pParam)
 				uid = strtok(NULL, " ");	
 				buf.Empty();
 				if(check_uid_cache(uid, uid_cache_path)){
-					buf.Format("%d/%d checking which is already received", i+1, how_many_mail);
+					buf.Format("%d/%d checking which is already received", cnt+1, how_many_mail);
 					av->SetStatusBarText(buf.GetBuffer(0), account);
 					buf.Empty();
-					if(i+1 == how_many_mail){
+					if(cnt+1 == how_many_mail){
 						WritePrivateProfileString("pop", "last_uid", uid, path);
 					}
+					if(delete_mail){
+						wsprintf(dele, "dele %d\r\n", cnt+1);
+						send(pop_socket.m_sock, dele , strlen(dele), 0);
+						pop_socket.SockRead(buf);
+						buf.Empty();
+					}
 					uid.Empty();
 					continue;
 				}
 			}
 
 			// getting size of mail (may be no need)
-			wsprintf(list, "list %d\r\n", i+1);
+			wsprintf(list, "list %d\r\n", cnt+1);
 			send(pop_socket.m_sock, list, strlen(list), 0);
 			pop_socket.SockRead(buf);
 			token = strtok(buf.GetBuffer(0), " ");
@@ -286,7 +314,7 @@ UINT FetchMail(LPVOID pParam)
 			buf.Empty();
 
 			// sending retr command
-			wsprintf(retr, "retr %d\r\n", i+1);
+			wsprintf(retr, "retr %d\r\n", cnt+1);
 			send(pop_socket.m_sock, retr , strlen(retr), 0);
 			pop_socket.SockRead(buf);
 			buf.Empty();
@@ -309,7 +337,7 @@ UINT FetchMail(LPVOID pParam)
 					mail.Add(buf);
 
 					// display some info about current fetching mail on statusbar.
-					message.Format("%d/%d %s", i+1, how_many_mail, hi.GetSubject());
+					message.Format("%d/%d %s", cnt+1, how_many_mail, hi.GetSubject());
 					av->SetStatusBarText(message.GetBuffer(0), account);
 					is_header = FALSE;
 					continue;
@@ -321,7 +349,7 @@ UINT FetchMail(LPVOID pParam)
 					buf.Delete(0, 1);
 				}
 				mail.Add(buf);
-				message.Format("%d/%d %d/%d %s", i+1, how_many_mail, get_size, mail_size, hi.GetSubject());
+				message.Format("%d/%d %d/%d %s", cnt+1, how_many_mail, get_size, mail_size, hi.GetSubject());
 				av->SetStatusBarText(message.GetBuffer(0), account);
 			}
 			if(g_cstra_getsize(mail) == 0){
@@ -329,7 +357,7 @@ UINT FetchMail(LPVOID pParam)
 			}
 #endif
 			// vOXo[is
-			av->SetStatusBarProgress(i+1-start, how_many_mail-start, account);
+			av->SetStatusBarProgress(cnt+1-start, how_many_mail-start, account);
 
 			// 擾[ۑpX->tB^̎͂
 			CString mail_path = filter.GetPath(hi);
@@ -356,7 +384,7 @@ UINT FetchMail(LPVOID pParam)
 #endif
 			// lastuid.iniuidLbVt@CɊi[
 			if(uid.IsEmpty()){
-				wsprintf(uidl, "uidl %d\r\n", i+1);
+				wsprintf(uidl, "uidl %d\r\n", cnt+1);
 				send(pop_socket.m_sock, uidl, strlen(uidl), 0);
 				pop_socket.SockRead(buf);
 				buf.TrimRight();
@@ -370,7 +398,7 @@ UINT FetchMail(LPVOID pParam)
 				WritePrivateProfileString("pop", "last_uid", uid, path);
 			}
 
-			CStdioFile UidCacheWrite; // uidLbVۑp
+			CStdioFile UidCacheWrite; // for uid cache saving
 			if(!UidCacheWrite.Open(uid_cache_path.GetBuffer(1), 
 								 CFile::modeWrite |
 								 CFile::modeCreate |
@@ -388,9 +416,9 @@ UINT FetchMail(LPVOID pParam)
 			buf.Empty();
 			mail.RemoveAll();
 
-			// deleR}h̑o
-			if(delete_mail == 1){
-				wsprintf(dele, "dele %d\r\n", i+1);
+			// delete mail
+			if(delete_mail){
+				wsprintf(dele, "dele %d\r\n", cnt+1);
 				send(pop_socket.m_sock, dele , strlen(dele), 0);
 				pop_socket.SockRead(buf);
 				buf.Empty();
@@ -433,14 +461,14 @@ UINT FetchMail(LPVOID pParam)
 		}
 		av->SetStatusBarProgress(0, 100, account);
 		av->SetStatusBarText("", account);
-		mf->UpdateButton(TRUE, account);
+		mf->UpdateButton1(TRUE, account);
 		av->SetFetchStatus(account.GetBuffer(0), FALSE);
 		mf->StopTaskTrayAnimation();
 		return FALSE;
 	}
 
 	// Ct[̎M{^Lɂ
-	mf->UpdateButton(TRUE, account);
+	mf->UpdateButton1(TRUE, account);
 
 	av->SetFetchStatus(account.GetBuffer(0), FALSE);
 	av->SetStatusBarText(buf.GetBuffer(0), account);
