@@ -18,6 +18,9 @@
 #include "SortStringArray.h"
 #include "lib.h"
 #include "direct.h"			// _mkdir
+#pragma warning (push, 1)
+#include <sstream>
+#pragma warning (pop)
 
 #ifdef _DEBUG
 #define new DEBUG_NEW
@@ -46,7 +49,6 @@ BEGIN_MESSAGE_MAP(CFolderView, CBitmapTreeView)
 	//{{AFX_MSG_MAP(CFolderView)
 	ON_NOTIFY_REFLECT(TVN_SELCHANGED, OnSelchanged)
 	ON_NOTIFY_REFLECT(TVN_ITEMEXPANDED, OnItemexpanded)
-	ON_WM_CHAR()
 	ON_NOTIFY_REFLECT(TVN_SELCHANGING, OnSelchanging)
 	ON_WM_KEYDOWN()
 	ON_WM_SETFOCUS()
@@ -62,6 +64,8 @@ BEGIN_MESSAGE_MAP(CFolderView, CBitmapTreeView)
 	ON_COMMAND(ID_FOLDERVIEW_RESTRUCT, OnPopupRebuild)
 	ON_WM_SIZE()
 	ON_COMMAND(ID_FOLDERVIEW_CLEAR_TRASH, OnPopupClearTrash)
+	ON_COMMAND(ID_NEXT_FOLDER, OnNextFolder)
+	ON_COMMAND(ID_PREV_FOLDER, OnPrevFolder)
 	//}}AFX_MSG_MAP
 END_MESSAGE_MAP()
 
@@ -260,9 +264,10 @@ void CFolderView::OnSelchanged(NMHDR* pNMHDR, LRESULT* pResult)
 	CString current_account;
 
 	// each button(reply, transfer, header info) is invalidate
-	mf->m_button_reply = FALSE;
+/*	mf->m_button_reply = FALSE;
 	mf->m_button_transfer = FALSE;
-	mf->m_button_info = FALSE;
+	mf->m_button_info = FALSE;*/
+	mf->UpdateButton2(FALSE);
 
 	// gpg button in toolbar is invalidate
 	mf->m_button_gpg_dec = FALSE;
@@ -371,30 +376,6 @@ CString CFolderView::GetTopItemName(HTREEITEM ti)
 	return name;
 }
 
-void CFolderView::OnChar(UINT nChar, UINT nRepCnt, UINT nFlags) 
-{
-	CPochyApp* app = (CPochyApp*)AfxGetApp();
-	CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;
-	CTreeCtrl& treeCtrl = GetTreeCtrl();
-	HTREEITEM ti;
-
-	if(mf->Char(nChar))
-		return;
-
-	switch(nChar){
-	case 'n':
-		ti = treeCtrl.GetNextItem(treeCtrl.GetSelectedItem(), TVGN_NEXTVISIBLE);
-		if(ti != NULL) treeCtrl.SelectItem(ti);
-		break;
-	case 'p':
-		ti = treeCtrl.GetNextItem(treeCtrl.GetSelectedItem(), TVGN_PREVIOUSVISIBLE);
-		if(ti != NULL) treeCtrl.SelectItem(ti);
-		break;
-	default:
-		break;
-	}
-}
-
 void CFolderView::OnSelchanging(NMHDR* pNMHDR, LRESULT* pResult) 
 {
 
@@ -467,7 +448,7 @@ void CFolderView::AddUser(CString path, CString user)
 	tc.SetItemData(tc.InsertItem(trash, 2, 2, hItem, TVI_LAST), FV_TRASH);
 
 	for(int i=0; i <= DirArray.GetUpperBound(); i++)
-		tc.SetItemData(tc.InsertItem(DirArray.GetAt(i).GetBuffer(0), 0, 1, hItem, TVI_LAST), FV_OTHER);
+		tc.SetItemData(tc.InsertItem(DirArray.GetAt(i), 0, 1, hItem, TVI_LAST), FV_OTHER);
 }
 
 void CFolderView::RemoveUser(CString user)
@@ -650,6 +631,7 @@ void CFolderView::OnLButtonUp(UINT nFlags, CPoint point)
 
 	if (m_bLDragging){
 		CPochyApp* app = (CPochyApp*)AfxGetApp();
+		CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;
 		CSummaryView* sv = ((CMainFrame*)app->m_pMainWnd)->m_pListV;
 		m_bLDragging = FALSE;
 		CImageList::DragLeave(this);
@@ -711,6 +693,8 @@ void CFolderView::OnLButtonUp(UINT nFlags, CPoint point)
 			default:
 				break;
 			}
+			// invalidate some button in toolbar
+			mf->UpdateButton2(FALSE);
         }
     }
 }
@@ -948,3 +932,149 @@ bool CFolderView::GetShowUnreadCount()
 {
 	return m_bShowUnreadCount;
 }
+
+void CFolderView::OnNextFolder()
+{
+	CTreeCtrl& treeCtrl = GetTreeCtrl();
+	HTREEITEM hSelectedTreeItem = treeCtrl.GetSelectedItem();
+	if (hSelectedTreeItem == NULL)
+	{
+		hSelectedTreeItem = treeCtrl.GetRootItem();
+	}
+	HTREEITEM hNextTreeItem = treeCtrl.GetNextItem(hSelectedTreeItem, TVGN_NEXTVISIBLE);
+	if (hNextTreeItem == NULL)
+	{
+		hNextTreeItem = treeCtrl.GetRootItem();
+	}
+	if (hNextTreeItem != NULL && hNextTreeItem != hSelectedTreeItem)
+	{
+		treeCtrl.SelectItem(hNextTreeItem);
+	}
+}
+
+void CFolderView::OnPrevFolder()
+{
+	CTreeCtrl& treeCtrl = GetTreeCtrl();
+	HTREEITEM hSelectedTreeItem = treeCtrl.GetSelectedItem();
+	if (hSelectedTreeItem == NULL)
+	{
+		hSelectedTreeItem = treeCtrl.GetRootItem();
+	}
+	HTREEITEM hNextTreeItem = treeCtrl.GetNextItem(hSelectedTreeItem, TVGN_PREVIOUSVISIBLE);
+	if (hNextTreeItem == NULL)
+	{
+		hNextTreeItem = treeCtrl.GetFirstVisibleItem();
+		HTREEITEM hLastVisibleItem = NULL;
+		for (;;)
+		{
+			hLastVisibleItem = treeCtrl.GetNextVisibleItem(hNextTreeItem);
+			if (hLastVisibleItem != NULL)
+			{
+				hNextTreeItem = hLastVisibleItem;
+			}
+			else
+			{
+				break;
+			}
+		}
+	}
+	if (hNextTreeItem != NULL && hNextTreeItem != hSelectedTreeItem)
+	{
+		treeCtrl.SelectItem(hNextTreeItem);
+	}
+}
+
+// path ɑtH_[I
+// Ă珇ɊJ
+void CFolderView::SelectFolder(const std::string &path)
+{
+	if (path != _T(""))
+	{
+		CPochyApp* pApp = (CPochyApp*)::AfxGetApp();
+		std::string shortPath = path.substr(pApp->m_app_path.GetLength() + 1);
+		std::vector<std::string> shortPathList;
+
+		std::string str;
+		std::istringstream sin(shortPath);
+		while(std::getline(sin, str, _T('\\')))
+		{
+			if (str != _T(""))
+			{
+				shortPathList.push_back(str);
+			}
+		}
+
+		// [g}Ɍ
+		CTreeCtrl& treeCtrl = GetTreeCtrl();
+		HTREEITEM hTreeItem = treeCtrl.GetRootItem();
+		std::string targetPath;
+		HTREEITEM hTargetTree = NULL;
+//		SetRedraw(FALSE);
+		int i;
+		for (i = 0; i < shortPathList.size(); i++)
+		{
+			targetPath += _T("\\") + shortPathList[i];
+			hTargetTree = FindFolder(hTreeItem, targetPath);
+			if (hTargetTree != NULL)
+			{
+				if (i != shortPathList.size() - 1)
+				{
+					// ̂rȂ}J
+					treeCtrl.Expand(hTargetTree, TVE_EXPAND);
+				}
+				hTreeItem = hTargetTree;
+			}
+		}
+//		SetRedraw(TRUE);
+		if (hTargetTree != NULL)
+		{
+			treeCtrl.SelectItem(hTargetTree);
+		}
+	}
+}
+
+// path ɑtH_[
+// łɍĂ̂Ȃ
+HTREEITEM CFolderView::FindFolder(HTREEITEM hTreeItem, const std::string &path)
+{
+	HTREEITEM hResult = NULL;
+
+	if (hTreeItem != NULL)
+	{
+		if (GetItemPath(hTreeItem) == path.c_str())
+		{
+			hResult = hTreeItem;
+		}
+		else
+		{
+			CTreeCtrl& treeCtrl = GetTreeCtrl();
+			hTreeItem = treeCtrl.GetChildItem(hTreeItem);
+			while(hTreeItem)
+			{
+				if (GetItemPath(hTreeItem) == path.c_str())
+				{
+					return hTreeItem;
+				}
+				else
+				{
+					HTREEITEM hSubItem = FindFolder(hTreeItem, path);
+					if (hSubItem != NULL)
+					{
+						return hSubItem;
+					}
+				}
+				hTreeItem = treeCtrl.GetNextSiblingItem(hTreeItem);
+			}
+		}
+	}
+
+	return hResult;
+}
+
+int CFolderView::GetCurrentItemKind()
+{
+	CTreeCtrl& tc = GetTreeCtrl();
+	HTREEITEM ti = tc.GetSelectedItem();
+
+	return WhatKind(ti);
+}
