@@ -243,7 +243,7 @@ CString CHeaderInfo::GetOneLine(LPCTSTR key)
 		buf = m_decoded_header.GetAt(n);
 
 		if(0 == regexec(&reg, buf.GetBuffer(0), 1, pmatch, 0)){
-			delete r;
+			delete[] r;
 			buf.ReleaseBuffer();
 			regfree(&reg);
 			return buf;
@@ -253,7 +253,7 @@ CString CHeaderInfo::GetOneLine(LPCTSTR key)
 	}
 
 	regfree(&reg);
-	delete r;
+	delete[] r;
 	buf.Empty();
 	return buf; // if nothing is matched, return empty
 }
@@ -333,11 +333,8 @@ void CHeaderInfo::Decode()
 	// folding white space 
 	RemoveFoldingWhiteSpace(&header);
 
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
 	// linear white space
 	RemoveLinearWhiteSpace(&header);
-// end
 
 	while(n < header.GetSize()){
 		buf = header.GetAt(n);
@@ -368,6 +365,7 @@ void CHeaderInfo::Decode()
 			}
 
 			if(encode_type == "Q" || encode_type == "q"){
+				char_encoded.Replace("_", " ");
 				len = fromQPtobits(temp2.GetBuffer(char_encoded.GetLength()), char_encoded.GetBuffer(0), char_encoded.GetLength());
 				temp2.ReleaseBuffer(len);
 				char_encoded.ReleaseBuffer();
@@ -550,7 +548,7 @@ CString CHeaderInfo::ReformDate(CString buf)
 		CString loc_hour;
 		CString loc_minute;
 		CString loc_zone;
-		// not offset
+		// if not offset
 		if(!zone.SpanExcluding("0123456789+-").IsEmpty()){
 			zone = g_get_tzoffset_from_tzname(zone);
 		}
@@ -676,8 +674,6 @@ void CHeaderInfo::InitMemVal()
 	m_enc = SEVEN_BIT; // 7bit
 }
 
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
 void CHeaderInfo::RemoveLinearWhiteSpace(CStringArray *header)
 {
 	CString buf1;
@@ -704,4 +700,3 @@ void CHeaderInfo::RemoveLinearWhiteSpace(CStringArray *header)
 	}
 	regfree(&reg);
 }
-// end
\ No newline at end of file
