@@ -50,8 +50,7 @@ protected:
 	// ꂽbZ[W }bv֐
 protected:
 	//{{AFX_MSG(CHeaderView)
-	afx_msg void OnLink(NMHDR* in_pNotifyHeader, LRESULT* out_pResult);
-	afx_msg void OnChar(UINT nChar, UINT nRepCnt, UINT nFlags);
+	afx_msg BOOL OnLink(NMHDR* in_pNotifyHeader, LRESULT* out_pResult);
 	//}}AFX_MSG
 	DECLARE_MESSAGE_MAP()
 private:
