@@ -32,7 +32,7 @@ BEGIN_MESSAGE_MAP(CMailEditView, CBitmapRichEditView)
 	//{{AFX_MSG_MAP(CMailEditView)
 	ON_WM_CHAR()
 	ON_WM_KEYDOWN()
-	ON_COMMAND(ID_EDIT_PASTE, OnEditPaste)
+//	ON_COMMAND(ID_EDIT_PASTE, OnEditPaste)
 	ON_WM_RBUTTONDOWN()
 	ON_COMMAND(ID_EDITVIEW_PASTE, OnEditviewPaste)
 	ON_COMMAND(ID_EDITVIEW_COPY, OnEditviewCopy)
@@ -241,7 +241,7 @@ void CMailEditView::OnChar(UINT nChar, UINT nRepCnt, UINT nFlags)
 			return;
 	}
 
-	long a,b;
+	/*	long a,b;
 	int y;
 
 	CRichEditCtrl& r = GetRichEditCtrl();
@@ -276,18 +276,30 @@ void CMailEditView::OnChar(UINT nChar, UINT nRepCnt, UINT nFlags)
 		case 32:
 			if(a!=b)
 				r.SetSel(b,b);
-		}
-		CRichEditView::OnChar(nChar, nRepCnt, nFlags);
+	}*/
+	CRichEditView::OnChar(nChar, nRepCnt, nFlags);
 }
 
 void CMailEditView::OnKeyDown(UINT nChar, UINT nRepCnt, UINT nFlags) 
 {
 	CPochyApp* app = (CPochyApp*)AfxGetApp();
 	CDraftFrame* df = (CDraftFrame*)GetParentFrame();
+
 	if(app->GetProfileInt("Customize", "MewKeyBind", 0)){
 		if(df->KeyDown(nChar,this))
 			return;
 	}
+
+	if(::GetKeyState(VK_CONTROL) & 0xff00){	
+		switch(nChar){
+		case 'V':
+			this->OnEditviewPaste();
+			return;
+		default:
+			break;
+		}
+	}
+
 	CBitmapRichEditView::OnKeyDown(nChar, nRepCnt, nFlags);
 }
 
@@ -471,9 +483,10 @@ void CMailEditView::Font()
 	DeleteFile("tmpfile");
 }*/
 
+/*
 void CMailEditView::OnEditPaste() 
 {
-	char * buffer;
+	char *buffer;
 
 	if(OpenClipboard()){
 		HANDLE hData = ::GetClipboardData(CF_TEXT);
@@ -496,9 +509,33 @@ void CMailEditView::OnEditPaste()
 		CloseClipboard();
 	}
 	GetRichEditCtrl().Paste();
-}
 
-void CMailEditView::OnLink( NMHDR* in_pNotifyHeader, LRESULT* out_pResult )
+	char * buffer;
+
+	if(OpenClipboard()){
+		HANDLE hData = ::GetClipboardData(CF_TEXT);
+		buffer = (char*)GlobalLock(hData);
+		GlobalUnlock(hData);
+		CloseClipboard();
+	}
+
+	CString source;
+	source=buffer;
+
+	if(OpenClipboard()){
+		HGLOBAL clipbuffer;
+		EmptyClipboard();
+		clipbuffer = GlobalAlloc(GMEM_DDESHARE, source.GetLength()+1);
+		buffer = (char*)GlobalLock(clipbuffer);
+		strcpy(buffer, LPCSTR(source));
+		GlobalUnlock(clipbuffer);
+		SetClipboardData(CF_TEXT,clipbuffer);
+		CloseClipboard();
+	}
+	GetRichEditCtrl().PasteSpecial(CF_TEXT);
+}*/
+
+BOOL CMailEditView::OnLink( NMHDR* in_pNotifyHeader, LRESULT* out_pResult )
 {
 	*out_pResult = 0;
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
@@ -534,8 +571,19 @@ void CMailEditView::OnLink( NMHDR* in_pNotifyHeader, LRESULT* out_pResult )
 			app->CreateDraftFrame(mf->m_pAcntV->GetCurrentAccountName());
 		}
 		else
-			ShellExecute(this->GetSafeHwnd(), _T( "open" ), link, NULL, NULL, SW_SHOWNORMAL);
+		{
+			CString strBrowserPath = app->GetProfileString(_T("Customize"), _T("BrowserPath"), _T(""));
+			if (strBrowserPath != _T(""))
+			{
+				::ShellExecute(NULL, NULL, strBrowserPath, link, NULL, SW_SHOWNORMAL);
+			}
+			else
+			{
+				ShellExecute(this->GetSafeHwnd(), _T( "open" ), link, NULL, NULL, SW_SHOWNORMAL);
+			}
+		}
 	}
+	return TRUE;
 }
 
 void CMailEditView::OnRButtonDown(UINT nFlags, CPoint point) 
@@ -599,7 +647,7 @@ void CMailEditView::OnEditviewPaste()
 		SetClipboardData(CF_TEXT,clipbuffer);
 		CloseClipboard();
 	}
-	GetRichEditCtrl().Paste();
+	GetRichEditCtrl().PasteSpecial(CF_TEXT);
 }
 
 void CMailEditView::OnEditviewCopy() 
@@ -610,7 +658,7 @@ void CMailEditView::OnEditviewCopy()
 
 void CMailEditView::OnEditviewSelall() 
 {
-	// ׂđI
+	// select all
 	CRichEditCtrl &r = GetRichEditCtrl();
 	r.SetSel(0, -1);	
 }
@@ -629,7 +677,6 @@ void CMailEditView::OnEditviewUndo()
 
 int CMailEditView::GetPos()
 {
-//	CDraftFrame* df = (CDraftFrame*)GetParentFrame();
 	CPoint p;
 	p = GetCaretPos();
 	return p.x/m_font_size-1;
