@@ -27,11 +27,11 @@
 #include "GpgDlg.h"
 #include "MainAddressBookDlg.h"
 #include "SettingGeneralDlg.h"
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
 #include "Template.h"
 #include "MainAddressCheckDlg.h"
-// end
+#pragma warning (push, 1)
+#include <algorithm>
+#pragma warning (pop)
 
 #ifdef _DEBUG
 #define new DEBUG_NEW
@@ -58,23 +58,22 @@ BEGIN_MESSAGE_MAP(CMainFrame, CFrameWnd)
 	ON_COMMAND(ID_GPG, OnGpg)
 	ON_UPDATE_COMMAND_UI(ID_GPG_DEC, OnUpdateGpgDec)
 	ON_UPDATE_COMMAND_UI(ID_GPG, OnUpdateGpg)
+	ON_UPDATE_COMMAND_UI(ID_GPG_MAIN_KEY_MANAGEMENT, OnUpdateGpg)
 	ON_COMMAND(ID_RETRIEVE, OnRetrieve)
 	ON_WM_DESTROY()
 	ON_COMMAND(ID_SETTING, OnSetting)
 	ON_COMMAND(ID_REPLY, OnReply)
 	ON_COMMAND(ID_DRAFT, OnDraft)
+	ON_COMMAND(ID_DRAFT_DEFAULT, OnDraft)
 	ON_COMMAND(ID_ADDRESS, OnAddress)
 	ON_UPDATE_COMMAND_UI(ID_TRANSFER, OnUpdateTransfer)
 	ON_COMMAND(ID_INFO, OnInfo)
 	ON_UPDATE_COMMAND_UI(ID_INFO, OnUpdateInfo)
+	ON_UPDATE_COMMAND_UI(ID_DISPLAY_HEADER, OnUpdateInfo)
+	ON_UPDATE_COMMAND_UI(ID_DISPLAY_RAW_MAIL, OnUpdateInfo)
 	ON_UPDATE_COMMAND_UI(ID_SETTING, OnUpdateSetting)
 	ON_NOTIFY(TBN_DROPDOWN, AFX_IDW_TOOLBAR, OnToolbarDropDown)
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
-//	ON_COMMAND(ID_REPLY_QUOTATION, OnReplyQuotation)
-//	ON_COMMAND(ID_REPLY_NO_QUOTATION, OnReplyNoQuotation)
 	ON_COMMAND(ID_REPLY_DEFAULT, OnReply)
-// end
 	ON_WM_TIMER()
 	ON_COMMAND(ID_SETTING_GENERAL, OnSettingGeneral)
 	ON_COMMAND(ID_SETTING_ACCOUNT, OnSettingAccount)
@@ -84,6 +83,8 @@ BEGIN_MESSAGE_MAP(CMainFrame, CFrameWnd)
 	ON_COMMAND(ID_SETTING_NEW_ACCOUNT, OnSettingNewAccount)
 	ON_COMMAND(ID_TRANSFER_QUOTATION, OnTransferQuotation)
 	ON_COMMAND(ID_GPG_MAIN_KEY_MANAGEMENT, OnGpgKeyManagement)
+	ON_COMMAND(ID_SWITCH_VIEW, OnSwitchView)
+	ON_COMMAND(ID_SCROLL_MAIL, OnScrollMail)
 	ON_WM_CLOSE()
 	ON_WM_COPYDATA()
 	ON_WM_SYSCOMMAND()
@@ -114,11 +115,8 @@ CMainFrame::CMainFrame() : m_hRichEdit20(NULL)
 	m_button_info = FALSE;
 	m_tasktray_animation_num = 0;
 	m_hRichEdit20 = ::LoadLibraryA("RichEd20.dll");
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
 	// for dynamic drop down menu
 	this->m_bAutoMenuEnable = FALSE;
-// end
 }
 
 CMainFrame::~CMainFrame()
@@ -333,8 +331,11 @@ void CMainFrame::SetStatusBarText(int pane, LPCSTR buf)
 
 void CMainFrame::OnFetchmail()
 {
-	this->m_pAcntV->SetFetchStatus(this->m_pAcntV->GetCurrentAccountName(), TRUE);
-	AfxBeginThread(FetchMail, this->m_pAcntV->GetCurrentAccountName());
+	if(!m_pAcntV->IsFetching(m_pAcntV->GetCurrentAccountName()))
+	{
+		this->m_pAcntV->SetFetchStatus(this->m_pAcntV->GetCurrentAccountName(), TRUE);
+		AfxBeginThread(FetchMail, this->m_pAcntV->GetCurrentAccountName());
+	}
 }
 
 void CMainFrame::OnUpdateFetchmail(CCmdUI* pCmdUI)
@@ -567,10 +568,11 @@ typedef struct tagLOGFONT { // lf
 		app->m_draft_array[i]->DestroyWindow();
 	}
 
-	// clear away temporary folder
-//	if(g_is_there(app->m_app_path+"\\temp")){
-//		g_rm_recursive(app->m_app_path+"\\temp");
-//	}
+	// clear temporary folder
+	if(g_is_there(app->m_app_path+"\\temp")){
+		g_empty_directory(app->m_app_path+"\\temp");
+	}
+	
 
 	CFrameWnd::OnDestroy();
 }
@@ -582,10 +584,11 @@ void CMainFrame::OnSetting()
 
 void CMainFrame::OnReply() 
 {
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
-//	// ݒőIׂ悤ɂ
-//	this->OnReplyQuotation();
+	if(this->m_button_reply==FALSE)
+	{
+		return;
+	}
+
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
 	CTemplate tmpl;
 	CString body_tmpl;
@@ -672,8 +675,8 @@ void CMainFrame::OnReply()
 	// setting references
 	app->m_me.SetReferences(m_pTextV->GetCurrentMsgID());
 
-	if(g_is_there(app->m_app_path+"\\template\\default_q.rtmpl")){
-		g_file2cstring(app->m_app_path+"\\template\\default_q.rtmpl", body_tmpl);
+	if(g_is_there(app->m_app_path+"\\template\\default.rtmpl")){
+		g_file2cstring(app->m_app_path+"\\template\\default.rtmpl", body_tmpl);
 	}else{
 		body_tmpl = DEF_REPLY_TEMPLATE;
 	}
@@ -687,7 +690,6 @@ void CMainFrame::OnReply()
 
 	// create draft frame
 	app->CreateDraftFrame(this->m_pAcntV->GetCurrentAccountName());
-// end
 }
 
 void CMainFrame::OnDraft() 
@@ -712,11 +714,7 @@ void CMainFrame::OnDraft()
 
 	// setting "bcc" field
 	CString bcc;
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
-//	GetPrivateProfileString("def_address", "address", "", bcc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
 	GetPrivateProfileString("def_address", "bcc", "", bcc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
-// end
 	bcc.ReleaseBuffer();
 	app->m_me.SetBcc(bcc);
 
@@ -730,11 +728,25 @@ void CMainFrame::OnDraft()
 	app->m_me.SetMessageID(g_gen_msgid(from));
 
 	// getitng signature
+//	CString signature;
+//	g_file2cstring(app->m_app_path+"\\"+m_pAcntV->GetCurrentAccountName()+"\\signature", signature);
+
+	CTemplate tmpl;
+	CString body_tmpl;
+	if(g_is_there(app->m_app_path+"\\template\\default.dtmpl")){
+		g_file2cstring(app->m_app_path+"\\template\\default.dtmpl", body_tmpl);
+	}else{
+		body_tmpl = DEF_DRAFT_TEMPLATE;
+	}
+
 	CString signature;
 	g_file2cstring(app->m_app_path+"\\"+m_pAcntV->GetCurrentAccountName()+"\\signature", signature);
+	tmpl.SetSignature(signature);
+//	tmpl.SetBody(m_pTextV->GetCurrentBody());
 
 	// setting mail body
-	app->m_me.AddText("\r\n"+signature);
+//	app->m_me.AddText("\r\n"+signature);
+	app->m_me.AddText(tmpl.GetString(NULL, body_tmpl));
 
 	// create window
 	app->CreateDraftFrame(this->m_pAcntV->GetCurrentAccountName());
@@ -756,73 +768,7 @@ void CMainFrame::OnInfo()
 	this->OnDisplayHeader();
 }
 
-// OnChar͑啶A̋ʂ
-BOOL CMainFrame::Char(UINT nChar)
-{
-	int sc;
-	CRetrieve Retrieve;
-
-	CPochyApp* app = (CPochyApp*)AfxGetApp();
-	if(app->m_retrieving){//ESCL[ȊOȂ
-		if(nChar==27)
-			app->m_retrieving = 0;
-		return TRUE;
-	}
-
-	switch(nChar){
-		case 9:
-			Retrieve.GoRetrieve(m_pListV->m_path, CONTINUE);
-			break;
-		case 'i':
-			if(!m_pAcntV->IsFetching(m_pAcntV->GetCurrentAccountName()))
-				OnFetchmail();
-			return TRUE;
-		case 'w': // VK쐬
-			OnDraft();
-			return TRUE;
-		case 'a': // pȂԐM
-			if(this->m_button_reply==TRUE)
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
-//				OnReplyNoQuotation();
-			OnReply();
-// end
-			return TRUE;
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
-//		case 'A': // pԐM
-//			if(this->m_button_reply==TRUE)
-//				OnReplyQuotation();
-//			return TRUE;
-// end
-		case 'f': // ]
-			if(this->m_button_transfer==TRUE)
-				OnTransfer();
-			return TRUE;
-		case 'o': // EBhEtH[JẌړ
-			SwitchView();
-			return TRUE;
-//		case VK_RETURN:
-		case ' ': // textview̃XN[
-			m_pTextV->SetFocus();// tH[JXȂƁANbNƂɖ肪N
-			sc = m_pTextV->GetScrollPos(SB_VERT);
-			if(sc >= m_pTextV->GetScrollLimit(SB_VERT))
-				sc = -m_pTextV->GetRichEditCtrl().GetLineCount();
-			else
-				sc = 7;
-			m_pTextV->GetRichEditCtrl().LineScroll(sc);
-			return TRUE;
-		case 6: // Ctrl+f
-			OnRetrieve();
-			return TRUE;
-//		case 'r':
-//			this->m_pListV->ReBuildSummary(this->m_pListV->m_path, SMRY_COLUMN_FROM);
-//			return TRUE;
-	}
-	return FALSE;
-}
-
-void CMainFrame::SwitchView()
+void CMainFrame::OnSwitchView()
 {
 	CWnd* wnd = GetFocus();
 	if(wnd == m_pTreeV)
@@ -914,8 +860,12 @@ BOOL CMainFrame::CreateToolbar()
 
 	// dropdown menu
 	m_wndToolBar.GetToolBarCtrl().SetExtendedStyle(TBSTYLE_EX_DRAWDDARROWS);
+	// draft
+	DWORD style = m_wndToolBar.GetButtonStyle(m_wndToolBar.CommandToIndex(ID_DRAFT));
+	style |= TBSTYLE_DROPDOWN;
+	m_wndToolBar.SetButtonStyle(m_wndToolBar.CommandToIndex(ID_DRAFT), style);
 	// reply
-	DWORD style = m_wndToolBar.GetButtonStyle(m_wndToolBar.CommandToIndex(ID_REPLY));
+	style = m_wndToolBar.GetButtonStyle(m_wndToolBar.CommandToIndex(ID_REPLY));
 	style |= TBSTYLE_DROPDOWN;
 	m_wndToolBar.SetButtonStyle(m_wndToolBar.CommandToIndex(ID_REPLY), style);
 	// transfer
@@ -938,18 +888,20 @@ BOOL CMainFrame::CreateToolbar()
 	return TRUE;
 }
 
-void CMainFrame::OnToolbarDropDown(NMTOOLBAR* pnmtb, LRESULT *plr)
+BOOL CMainFrame::OnToolbarDropDown(NMHDR* pNMHDR, LRESULT *plr)
 {
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
 	CPochyApp* app = (CPochyApp*)AfxGetApp();
 	CFileFind ff;
-// end
 	CWnd *wnd = &m_wndToolBar;
 	UINT id;
 
+	NMTOOLBARA *pnmtb = (NMTOOLBARA *)pNMHDR;
+
 	// Switch on button command id's
 	switch (pnmtb->iItem){
+	case ID_DRAFT:
+		id = IDR_MAINFRAME_POPUP_DRAFT;
+		break;
 	case ID_REPLY:
 		id = IDR_MAINFRAME_POPUP_REPLY;
 		break;
@@ -966,7 +918,7 @@ void CMainFrame::OnToolbarDropDown(NMTOOLBAR* pnmtb, LRESULT *plr)
 		id = IDR_MAINFRAME_POPUP_SETTING;
 		break;
 	default:
-		return;
+		return TRUE;
 	}
 	
 	// load and display popup menu
@@ -975,11 +927,26 @@ void CMainFrame::OnToolbarDropDown(NMTOOLBAR* pnmtb, LRESULT *plr)
 	CMenu* pPopup = menu.GetSubMenu(0);
 	ASSERT(pPopup);
 
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
 	int i;
 	BOOL b;
 	switch(pnmtb->iItem){
+	case ID_DRAFT:
+		this->m_template_array.RemoveAll();
+		b = ff.FindFile(app->m_app_path+"\\template\\*.*");
+		while(b){
+			b = ff.FindNextFile();
+			if(!ff.IsDirectory() && !ff.IsDots()){
+				if(ff.GetFileName().Mid(ff.GetFileName().Find(".")+1) == "dtmpl"){
+					if(ff.GetFileName() != "default.dtmpl"){
+						this->m_template_array.Add(ff.GetFileName());
+					}
+				}
+			}
+		}
+		for(i=0; i<m_template_array.GetSize(); i++){
+			pPopup->AppendMenu(MF_STRING|MF_ENABLED, ID_DYNAMIC_DROP_DOWN_MENU_START+i, m_template_array.GetAt(i));
+		}
+		break;
 	case ID_REPLY:
 		this->m_template_array.RemoveAll();
 		b = ff.FindFile(app->m_app_path+"\\template\\*.*");
@@ -987,7 +954,9 @@ void CMainFrame::OnToolbarDropDown(NMTOOLBAR* pnmtb, LRESULT *plr)
 			b = ff.FindNextFile();
 			if(!ff.IsDirectory() && !ff.IsDots()){
 				if(ff.GetFileName().Mid(ff.GetFileName().Find(".")+1) == "rtmpl"){
-					this->m_template_array.Add(ff.GetFileName());
+					if(ff.GetFileName() != "default.rtmpl"){
+						this->m_template_array.Add(ff.GetFileName());
+					}
 				}
 			}
 		}
@@ -1002,7 +971,9 @@ void CMainFrame::OnToolbarDropDown(NMTOOLBAR* pnmtb, LRESULT *plr)
 			b = ff.FindNextFile();
 			if(!ff.IsDirectory() && !ff.IsDots()){
 				if(ff.GetFileName().Mid(ff.GetFileName().Find(".")+1) == "ftmpl"){
-					this->m_template_array.Add(ff.GetFileName());
+					if(ff.GetFileName() != "default.ftmpl"){
+						this->m_template_array.Add(ff.GetFileName());
+					}
 				}
 			}
 		}
@@ -1013,165 +984,16 @@ void CMainFrame::OnToolbarDropDown(NMTOOLBAR* pnmtb, LRESULT *plr)
 	default:
 		break;
 	}
-// end
 	
 	CRect rc;
 	wnd->SendMessage(TB_GETRECT, pnmtb->iItem, (LPARAM)&rc);
 	wnd->ClientToScreen(&rc);
 	
 	pPopup->TrackPopupMenu( TPM_LEFTALIGN | TPM_LEFTBUTTON | TPM_VERTICAL, rc.left, rc.bottom, this, &rc);
+
+	return TRUE;
 }
 
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
-/*
-void CMainFrame::OnReplyQuotation() 
-{
-	CPochyApp *app = (CPochyApp *)AfxGetApp();
-
-	// initialyze
-	app->m_me.Initialize();
-
-	// setting to, if reply-to exist, use reply-to address as to address
-	if(m_pTextV->GetCurrentReplyTo().IsEmpty()){
-		app->m_me.SetTo(m_pTextV->GetCurrentFrom());
-	}else{
-		app->m_me.SetTo(m_pTextV->GetCurrentReplyTo());
-	}
-
-	// setting cc
-	if(!m_pTextV->GetCurrentCc().IsEmpty())
-		app->m_me.SetCc(m_pTextV->GetCurrentCc());
-
-	// setting from
-	CString path = app->m_app_path+"\\"+m_pAcntV->GetCurrentAccountName()+"\\account.ini";
-	CString address;
-	GetPrivateProfileString("mailbox", "address", "", address.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
-	address.ReleaseBuffer();
-	app->m_me.SetFrom(address);
-
-	// setting subject
-	if(m_pTextV->GetCurrentSubject().Find("Re:") == 0 || m_pTextV->GetCurrentSubject().Find("RE:") == 0){
-		app->m_me.SetSubject(m_pTextV->GetCurrentSubject());
-	}else{
-		app->m_me.SetSubject("Re: "+m_pTextV->GetCurrentSubject());
-	}
-
-	// setting "cc" field
-	CString cc;
-	GetPrivateProfileString("def_address", "cc", "", cc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
-	cc.ReleaseBuffer();
-	app->m_me.SetCc(cc);
-
-	// setting "bcc" field
-	CString bcc;
-	GetPrivateProfileString("def_address", "address", "", bcc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
-	bcc.ReleaseBuffer();
-	app->m_me.SetBcc(bcc);
-
-	// setting "reply-to" field
-	CString reply_to;
-	GetPrivateProfileString("def_address", "reply_to", "", reply_to.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
-	reply_to.ReleaseBuffer();
-	app->m_me.SetReplyTo(reply_to);
-
-	// message-id
-	app->m_me.SetMessageID(g_gen_msgid(address));
-
-	// In-reply-to
-	app->m_me.SetInReplyTo(m_pTextV->GetCurrentMsgID());
-	// setting references
-	app->m_me.SetReferences(m_pTextV->GetCurrentMsgID());
-
-	// setting quotation
-	CString body = m_pTextV->GetCurrentBody();
-	body.Replace("\r\n","\r\n> ");
-	body = "> "+body+"\r\n";
-
-	// signature
-	CString signature;
-	g_file2cstring(app->m_app_path+"\\"+m_pAcntV->GetCurrentAccountName()+"\\signature", signature);
-
-	// setting mail body
-	app->m_me.AddText(body+"\r\n"+signature);
-
-	// create draft frame
-	app->CreateDraftFrame(this->m_pAcntV->GetCurrentAccountName());
-}
-
-void CMainFrame::OnReplyNoQuotation() 
-{
-	CPochyApp *app = (CPochyApp *)AfxGetApp();
-
-	// initialyze mimeencode class member
-	app->m_me.Initialize();
-
-	// To
-	if(!m_pTextV->GetCurrentReplyTo().IsEmpty())
-		app->m_me.SetTo(m_pTextV->GetCurrentReplyTo());
-	else
-		app->m_me.SetTo(m_pTextV->GetCurrentFrom());
-
-	// From
-	CString path = app->m_app_path+"\\"+m_pAcntV->GetCurrentAccountName()+"\\account.ini";
-	CString address;
-	GetPrivateProfileString("mailbox", "address", "", address.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
-	address.ReleaseBuffer();
-	app->m_me.SetFrom(address);
-
-	// setting "cc" field
-	CString cc;
-	GetPrivateProfileString("def_address", "cc", "", cc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
-	cc.ReleaseBuffer();
-	if(!m_pTextV->GetCurrentCc().IsEmpty() && !cc.IsEmpty()){
-		app->m_me.SetCc(m_pTextV->GetCurrentCc()+", "+cc);
-	}else if(!m_pTextV->GetCurrentCc().IsEmpty() && cc.IsEmpty()){
-		app->m_me.SetCc(m_pTextV->GetCurrentCc());
-	}else if(m_pTextV->GetCurrentCc().IsEmpty() && !cc.IsEmpty()){
-		app->m_me.SetCc(cc);
-	}
-	// setting "bcc" field
-	CString bcc;
-	GetPrivateProfileString("def_address", "address", "", bcc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
-	bcc.ReleaseBuffer();
-	app->m_me.SetBcc(bcc);
-
-	// setting "reply-to" field
-	CString reply_to;
-	GetPrivateProfileString("def_address", "reply_to", "", reply_to.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
-	reply_to.ReleaseBuffer();
-	app->m_me.SetReplyTo(reply_to);
-
-	// setting message-id
-	app->m_me.SetMessageID(g_gen_msgid(address));
-
-	// setting in-reply-to
-	app->m_me.SetInReplyTo(m_pTextV->GetCurrentMsgID());
-	// setting references
-	app->m_me.SetReferences(m_pTextV->GetCurrentMsgID());
-
-	// setting subject
-	if(m_pTextV->GetCurrentSubject().Find("Re:") == 0)
-		app->m_me.SetSubject(m_pTextV->GetCurrentSubject());
-	else if(m_pTextV->GetCurrentSubject().Find("RE:") == 0)
-		app->m_me.SetSubject(m_pTextV->GetCurrentSubject());
-	else
-		app->m_me.SetSubject("Re: "+m_pTextV->GetCurrentSubject());
-
-	CString signature;
-	g_file2cstring(app->m_app_path+"\\"+m_pAcntV->GetCurrentAccountName()+"\\signature", signature);
-
-	// setting body
-	MULTIPART_STRUCT2 data;
-	data.m_body = signature;
-	data.m_type = "Text/Plain; charset=ISO-2022-JP";
-	data.m_encoding_type = "7bit";
-	app->m_me.AddMultipart(data);
-
-	app->CreateDraftFrame(this->m_pAcntV->GetCurrentAccountName());
-}*/
-// end
-
 void CMainFrame::OnGpg()
 {
 	this->OnGpgKeyManagement();
@@ -1196,6 +1018,7 @@ void CMainFrame::ReArrangeSplit()
 
 void CMainFrame::HideMultiPartView(BOOL b)
 {
+	CWnd* pFocusWnd = GetFocus();
 	if(b && m_multipart_hide == FALSE){
 		m_split_multi_others.HideRow(1);
 		m_multipart_hide = TRUE;
@@ -1203,6 +1026,11 @@ void CMainFrame::HideMultiPartView(BOOL b)
 		m_split_multi_others.ShowRow();
 		m_multipart_hide = FALSE;
 	}
+	if (pFocusWnd == m_pTextV || pFocusWnd == m_pMultiV)
+	{
+		// HideRow ŃtH[JXt[ɈڂĂ܂ߖ߂
+		m_pTextV->SetFocus();
+	}
 }
 
 void CMainFrame::OnTimer(UINT nIDEvent) 
@@ -1213,12 +1041,22 @@ void CMainFrame::OnTimer(UINT nIDEvent)
 	CFrameWnd::OnTimer(nIDEvent);
 }
 
-void CMainFrame::UpdateButton(BOOL b, CString account)
+void CMainFrame::UpdateButton1(BOOL b, CString account)
 {
 	int index = m_pAcntV->GetAccountNum(account);
 	m_pAcntV->m_data[index].button_fetchmail = b;
 	m_pAcntV->m_data[index].button_setting = b;
 	m_pAcntV->m_data[index].button_retrieve = b;
+	this->Invalidate(TRUE);
+	this->RedrawWindow();
+}
+
+void CMainFrame::UpdateButton2(BOOL b)
+{
+	// each button(reply, transfer, header info) is invalidate
+	m_button_reply = b;
+	m_button_transfer = b;
+	m_button_info = b;
 }
 
 void CMainFrame::SetStatusBarProgress(int current, int upper)
@@ -1342,13 +1180,15 @@ void CMainFrame::OnSettingNewAccount()
 
 void CMainFrame::OnTransferQuotation() 
 {
+	if(this->m_button_transfer == FALSE)
+	{
+		return;
+	}
+
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
 	CTemplate tmpl;
 	CString body_tmpl;
 	CString signature;
-// end
 
 	// initialyze
 	app->m_me.Initialize();
@@ -1368,11 +1208,7 @@ void CMainFrame::OnTransferQuotation()
 
 	// setting "bcc" field
 	CString bcc;
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
-//	GetPrivateProfileString("def_address", "address", "", bcc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
 	GetPrivateProfileString("def_address", "bcc", "", bcc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
-// end
 	bcc.ReleaseBuffer();
 	app->m_me.SetBcc(bcc);
 
@@ -1387,32 +1223,6 @@ void CMainFrame::OnTransferQuotation()
 
 	// subject
 	app->m_me.SetSubject("Fw: "+m_pTextV->GetCurrentSubject());
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
-/*	// {Ɉpݒ
-	CString message;
-	message += "\r\nFowarded by ";
-	message += app->m_me.GetFrom()+"\r\n";
-	message += "----- Original Message -----\r\n";
-	if(!m_pTextV->GetCurrentFrom().IsEmpty())
-		message += "From: "+m_pTextV->GetCurrentFrom()+"\r\n";
-	if(!m_pTextV->GetCurrentTo().IsEmpty())
-		message += "To: "+m_pTextV->GetCurrentTo()+"\r\n";
-	if(!m_pTextV->GetCurrentCc().IsEmpty())
-		message += "Cc: "+m_pTextV->GetCurrentCc()+"\r\n";
-	if(!m_pTextV->GetCurrentDate())
-		message += "Date: "+m_pTextV->GetCurrentDate()+"\r\n";
-	if(!m_pTextV->GetCurrentSubject())
-		message += "Subject: "+m_pTextV->GetCurrentSubject()+"\r\n";
-	message += "---\r\n\r\n";
-
-	CString body = m_pTextV->GetCurrentBody();
-	body = message+body;
-	// {ɑ}i]Ȃ̂łȂĂǂHj
-	CString signature;
-	g_file2cstring(app->m_app_path+"\\"+m_pAcntV->GetCurrentAccountName()+"\\signature", signature);
-	// {ݒ
-	app->m_me.AddText(body+"\r\n"+signature);*/
 
 	if(g_is_there(app->m_app_path+"\\template\\default.ftmpl")){
 		g_file2cstring(app->m_app_path+"\\template\\default.ftmpl", body_tmpl);
@@ -1427,7 +1237,6 @@ void CMainFrame::OnTransferQuotation()
 
 	// setting mail body
 	app->m_me.AddText(tmpl.GetString(&(m_pTextV->m_md), body_tmpl));
-// end
 
 	app->CreateDraftFrame(this->m_pAcntV->GetCurrentAccountName());	
 }
@@ -1442,13 +1251,15 @@ void CMainFrame::OnClose()
 {
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
 
-	if(this->m_wndToolBar.IsWindowVisible()){
+	LONG lStyle = ::GetWindowLong(m_wndToolBar.GetSafeHwnd(), GWL_STYLE);
+	if ((lStyle & WS_VISIBLE) == WS_VISIBLE){
 		app->WriteProfileInt("ToolBar", "IsVisible", SW_SHOW);
 	}else{
 		app->WriteProfileInt("ToolBar", "IsVisible", SW_HIDE);
 	}
 
-	if(this->m_wndStatusBar.IsWindowVisible()){
+	lStyle = ::GetWindowLong(m_wndStatusBar.GetSafeHwnd(), GWL_STYLE);
+	if ((lStyle & WS_VISIBLE) == WS_VISIBLE){
 		app->WriteProfileInt("StatusBar", "IsVisible", SW_SHOW);
 	}else{
 		app->WriteProfileInt("StatusBar", "IsVisible", SW_HIDE);
@@ -1486,8 +1297,6 @@ BOOL CMainFrame::OnCopyData(CWnd* pWnd, COPYDATASTRUCT* pCopyDataStruct)
 				address.ReleaseBuffer();
 				app->m_me.SetFrom(address);
 
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
 				// setting "cc" field
 				CString cc;
 				GetPrivateProfileString("def_address", "cc", "", cc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
@@ -1505,7 +1314,6 @@ BOOL CMainFrame::OnCopyData(CWnd* pWnd, COPYDATASTRUCT* pCopyDataStruct)
 				GetPrivateProfileString("def_address", "reply_to", "", reply_to.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
 				reply_to.ReleaseBuffer();
 				app->m_me.SetReplyTo(reply_to);
-// end
 
 				// setting message-id
 				app->m_me.SetMessageID(g_gen_msgid(address));
@@ -1652,8 +1460,6 @@ void CMainFrame::HideHeaderView(BOOL b)
 	}
 }
 
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
 BOOL CMainFrame::OnCmdMsg(UINT nID, int nCode, void* pExtra, AFX_CMDHANDLERINFO* pHandlerInfo) 
 {
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
@@ -1666,7 +1472,57 @@ BOOL CMainFrame::OnCmdMsg(UINT nID, int nCode, void* pExtra, AFX_CMDHANDLERINFO*
 	if(pHandlerInfo == NULL && ID_DYNAMIC_DROP_DOWN_MENU_START <= nID && nID <= ID_DYNAMIC_DROP_DOWN_MENU_END){
 		if(nCode == CN_COMMAND){
 			menu_item = this->m_template_array.GetAt(nID-ID_DYNAMIC_DROP_DOWN_MENU_START);
-			if(menu_item.Mid(menu_item.Find(".")+1) == "rtmpl"){
+			if(menu_item.Mid(menu_item.Find(".")+1) == "dtmpl"){
+				
+				// initialyze
+				app->m_me.Initialize();
+
+				// setting from
+				CString path = app->m_app_path+"\\"+m_pAcntV->GetCurrentAccountName()+"\\account.ini";
+				CString address;
+				GetPrivateProfileString("mailbox", "address", "", address.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+				address.ReleaseBuffer();
+				app->m_me.SetFrom(address);
+
+				// setting default "cc"
+				CString cc;
+				GetPrivateProfileString("def_address", "cc", "", cc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+				cc.ReleaseBuffer();
+				if(!cc.IsEmpty()){
+					app->m_me.AddCc(cc);
+				}
+
+				// setting default "bcc"
+				CString bcc;
+				GetPrivateProfileString("def_address", "bcc", "", bcc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+				bcc.ReleaseBuffer();
+				if(!bcc.IsEmpty()){
+					app->m_me.AddBcc(bcc);
+				}
+
+				// setting "reply-to"
+				CString reply_to;
+				GetPrivateProfileString("def_address", "reply_to", "", reply_to.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+				reply_to.ReleaseBuffer();
+				if(!reply_to.IsEmpty()){
+					app->m_me.SetReplyTo(reply_to);
+				}
+
+				// message-id
+				app->m_me.SetMessageID(g_gen_msgid(address));
+
+				// preparing for signature and body
+				CString signature;
+				g_file2cstring(app->m_app_path+"\\"+m_pAcntV->GetCurrentAccountName()+"\\signature", signature);
+				tmpl.SetSignature(signature);
+				g_file2cstring(app->m_app_path+"\\template\\"+menu_item, body_tmpl);
+				// setting mail body
+				app->m_me.AddText(tmpl.GetString(NULL, body_tmpl));
+
+				// create draft frame
+				app->CreateDraftFrame(this->m_pAcntV->GetCurrentAccountName());
+
+		}else if(menu_item.Mid(menu_item.Find(".")+1) == "rtmpl"){
 				
 				// initialyze
 				app->m_me.Initialize();
@@ -1814,4 +1670,318 @@ BOOL CMainFrame::OnCmdMsg(UINT nID, int nCode, void* pExtra, AFX_CMDHANDLERINFO*
 	}
 	return CFrameWnd::OnCmdMsg(nID, nCode, pExtra, pHandlerInfo);
 }
-// end
\ No newline at end of file
+
+bool CMainFrame::CreateFolderList(const std::string& path, std::vector<std::string>& folderList)
+{
+	bool bResult = false;
+
+	if (path.length() > 0)
+	{
+		WIN32_FIND_DATA findFileData;
+		HANDLE hFindFile = ::FindFirstFile((path + _T("\\*.*")).c_str(), &findFileData);
+		if (hFindFile != INVALID_HANDLE_VALUE)
+		{
+			while (::FindNextFile(hFindFile, &findFileData) != 0)
+			{
+				if ((findFileData.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY) == FILE_ATTRIBUTE_DIRECTORY &&
+					_tcscmp(findFileData.cFileName, _T("inbox")) != 0 &&
+					_tcscmp(findFileData.cFileName, _T("outbox")) != 0 &&
+					_tcscmp(findFileData.cFileName, _T("draft")) != 0 &&
+					_tcscmp(findFileData.cFileName, _T("trash")) != 0 &&
+					_tcscmp(findFileData.cFileName, _T(".")) != 0 &&
+					_tcscmp(findFileData.cFileName, _T("..")) != 0)
+				{
+					std::string fullPath = path + _T("\\") + findFileData.cFileName;
+					folderList.push_back(fullPath);
+					CreateFolderList(fullPath, folderList);
+				}
+			}
+			::FindClose(hFindFile);
+		}
+	}
+
+	return bResult;
+}
+
+bool CMainFrame::SelectNextUnreadFolder()
+{
+	bool bResult = false;
+
+	CPochyApp* pApp = (CPochyApp*)::AfxGetApp();
+	CMainFrame* pMainFrame = (CMainFrame*)pApp->m_pMainWnd;
+	CAccountView* pAccountView = (CAccountView*)pMainFrame->m_pAcntV;
+	CFolderView* pFolderView = (CFolderView*)pMainFrame->m_pTreeV;
+
+	HTREEITEM hTreeItem = pFolderView->GetTreeCtrl().GetSelectedItem();
+	std::string selectedFolderPath = pFolderView->GetItemPath(hTreeItem);
+	if (selectedFolderPath != _T(""))
+	{
+		// IĂtH_[̈ʒuL
+		selectedFolderPath = (std::string)pApp->m_app_path + selectedFolderPath;
+	}
+
+	int nAccountCount = pAccountView->m_data.GetSize();
+	int nAccount = pAccountView->m_index;
+	if (nAccount < 0)
+	{
+		nAccount = 0;
+	}
+	if (nAccountCount > 0)
+	{
+		std::string unreadFolderPath;
+		do // AJEg̐JԂ
+		{
+			// ǃtH_[OƂătH_[̃Xg
+			std::vector<std::string> folderList;
+			std::string path = pApp->m_app_path + _T("\\") + pAccountView->m_data[nAccount].account_name;
+
+			// tH_[Xgǉ
+			folderList.push_back(path + _T("\\") + _T("inbox"));
+			CreateFolderList(path + _T("\\") + _T("inbox"), folderList);
+			folderList.push_back(path + _T("\\") + _T("outbox"));
+			CreateFolderList(path + _T("\\") + _T("outbox"), folderList);
+			folderList.push_back(path + _T("\\") + _T("draft"));
+			CreateFolderList(path + _T("\\") + _T("draft"), folderList);
+			folderList.push_back(path + _T("\\") + _T("trash"));
+			CreateFolderList(path + _T("\\") + _T("trash"), folderList);
+			// ʃtH_[Xgǉ
+			CreateFolderList(path, folderList);
+
+			unreadFolderPath = FindUnreadFolderPath(folderList, selectedFolderPath);
+
+			if (unreadFolderPath != _T(""))
+			{
+				break; // ǂtH_[甲
+			}
+
+			nAccount = (nAccount + 1) % nAccountCount;
+		}
+		while (nAccount != pAccountView->m_index);
+
+		if (unreadFolderPath != _T(""))
+		{
+			if (nAccount != pAccountView->m_index)
+			{
+				// ǂAJEgɕύX
+				pAccountView->SelectAccount(nAccount);
+			}
+
+			// ǂtH_[I
+			// ĂJ
+			pFolderView->SelectFolder(unreadFolderPath);
+
+			bResult = true;
+		}
+	}
+
+	return bResult;
+}
+
+// tH_[XgɖǂtH_[
+// startFolderPath ꏄ
+const std::string CMainFrame::FindUnreadFolderPath(const std::vector<std::string>& folderList, const std::string& startFolderPath)
+{
+	CPochyApp* pApp = (CPochyApp*)::AfxGetApp();
+	CMainFrame* pMainFrame = (CMainFrame*)pApp->m_pMainWnd;
+	CSummaryView* pSummaryView = (CSummaryView*)pMainFrame->m_pListV;
+
+	std::vector<std::string>::const_iterator it,
+		selected_it = std::find(folderList.begin(), folderList.end(), startFolderPath);
+
+	for (it = selected_it; it != folderList.end(); ++it)
+	{
+		int nUnread = pSummaryView->GetUnreadCount(it->c_str());
+		if (nUnread > 0)
+		{
+			return *it; // ǂtH_[甲
+		}
+	}
+
+	for (it = folderList.begin(); it != selected_it; ++it)
+	{
+		int nUnread = pSummaryView->GetUnreadCount(it->c_str());
+		if (nUnread > 0)
+		{
+			return *it; // ǂtH_[甲
+		}
+	}
+
+	return _T("");
+}
+
+void CMainFrame::OnScrollMail()
+{
+	int sc;
+	m_pTextV->SetFocus();// tH[JXȂƁANbNƂɖ肪N
+	sc = m_pTextV->GetScrollPos(SB_VERT);
+	if(sc >= m_pTextV->GetScrollLimit(SB_VERT))
+		sc = -m_pTextV->GetRichEditCtrl().GetLineCount();
+	else
+		sc = 7;
+	m_pTextV->GetRichEditCtrl().LineScroll(sc);
+}
+
+BOOL CMainFrame::PreTranslateMessage(MSG* pMsg) 
+{
+	if (pMsg->message == WM_CHAR)
+	{
+		CPochyApp* app = (CPochyApp*)AfxGetApp();
+		if(app->m_retrieving)
+		{
+			//ESCL[ȊOȂ
+			if (LOWORD(pMsg->wParam) == VK_ESCAPE)
+			{
+				app->m_retrieving = 0;
+			}
+			return TRUE;
+		}
+	}
+
+	if (m_acceleratorTable.TranslateAccelerator(m_hWnd, pMsg))
+	{
+		return TRUE;
+	}
+	
+	return CFrameWnd::PreTranslateMessage(pMsg);
+}
+
+BOOL CMainFrame::OnCommand(WPARAM wParam, LPARAM lParam) 
+{
+	switch (LOWORD(wParam))
+	{
+	case ID_CHECK_DELETE_MARK:
+	case ID_UNCHECK_DELETE_MARK:
+	case ID_EXECUTE_DELETE_MARK:
+	case ID_SELECT_TOP_MAIL:
+	case ID_SELECT_BOTTOM_MAIL:
+	case ID_SUMMARYVIEW_REBUILD:
+	case ID_NEXT_MAIL:
+	case ID_PREV_MAIL:
+	case ID_NEXT_UNREAD_MAIL:
+		{
+			// Summary View ̃CxgđM
+			return ::SendMessage(m_pListV->GetSafeHwnd(), WM_COMMAND, wParam, lParam);
+		}
+		break;
+
+	case ID_NEXT_FOLDER:
+	case ID_PREV_FOLDER:
+		{
+			// Folder View ̃CxgđM
+			return ::SendMessage(m_pTreeV->GetSafeHwnd(), WM_COMMAND, wParam, lParam);
+		}
+		break;
+
+	case ID_NEXT_ACCOUNT:
+	case ID_PREV_ACCOUNT:
+		{
+			// Account View ̃CxgđM
+			return ::SendMessage(m_pAcntV->GetSafeHwnd(), WM_COMMAND, wParam, lParam);
+		}
+		break;
+
+	case ID_PAGE_UP:
+	case ID_PAGE_DOWN:
+	case ID_SCROLL_AND_NEXT_UNREAD:
+		{
+			// Text View ̃CxgđM
+			return ::SendMessage(m_pTextV->GetSafeHwnd(), WM_COMMAND, wParam, lParam);
+		}
+		break;
+	}
+
+	return CFrameWnd::OnCommand(wParam, lParam);
+}
+
+void CMainFrame::LoadAccelerator()
+{
+	CPochyApp *app = (CPochyApp*)AfxGetApp();
+	std::string strKeyIniPath = app->m_app_path + _T("\\KeySetting.ini");
+//	m_acceleratorTable.Save(strKeyIniPath, _T("MainFrameKey"));
+	m_acceleratorTable.Load(strKeyIniPath, _T("MainFrameKey"));
+	HMENU hMenu = ::GetMenu(m_hWnd);
+	m_acceleratorTable.ModifyMenuCaption(hMenu);
+}
+
+void CMainFrame::SetAcceleratorTargetWindow()
+{
+//	m_acceleratorTable.AddTargetWindow(GetSafeHwnd());
+	m_acceleratorTable.AddTargetWindow(m_pListV->GetSafeHwnd());
+	m_acceleratorTable.AddTargetWindow(m_pAcntV->m_combo_account.GetSafeHwnd());
+	m_acceleratorTable.AddTargetWindow(m_pTreeV->GetSafeHwnd());
+	m_acceleratorTable.AddTargetWindow(m_pTextV->GetSafeHwnd());
+	m_acceleratorTable.AddTargetWindow(m_pHeadV->GetSafeHwnd());
+	m_acceleratorTable.AddTargetWindow(m_pMultiV->GetSafeHwnd());
+//	m_acceleratorTable.AddTargetWindow(m_pListV->GetParent()->GetSafeHwnd());
+}
+
+void CMainFrame::LoadDefaultAccelerator()
+{
+	m_acceleratorTable.DeleteAll();
+
+	////////////////// MainFrame ////////////////////////////////////////////////////////////////////////////////////////
+	// mail
+	m_acceleratorTable.AddAccelerator(_T("Receive"),			ID_FETCH_MAIL,				_T("i"),		_T("M(&V)"));
+	m_acceleratorTable.AddAccelerator(_T("ReplyMail"),			ID_REPLY,					_T("a"),		_T("ԐM(&R)"));
+//	m_acceleratorTable.AddAccelerator(_T("ReplyQuotation"),		ID_REPLY_QUOTATION,			_T("Shift+a"),	_T("pԐM));
+//	m_acceleratorTable.AddAccelerator(_T("ReplyNoQuotation"),	ID_REPLY_NO_QUOTATION,		_T("a"),		_T("pȂԐM"));
+	m_acceleratorTable.AddAccelerator(_T("Forward"),			ID_TRANSFER,				_T("f"),		_T("](&T)"));
+//	m_acceleratorTable.AddAccelerator(_T("ForwardMail"),		ID_TRANSFER_QUOTATION,		_T("f"),		_T("](&T)"));
+	m_acceleratorTable.AddAccelerator(_T("NewMail"),			ID_DRAFT,					_T("w"),		_T("M(&N)"));
+	m_acceleratorTable.AddAccelerator(_T("Find"),				ID_RETRIEVE,				_T("Ctrl+F"),	_T("(&F)"));
+
+	// GPG
+	m_acceleratorTable.AddAccelerator(_T("GPGKeyManagement"),	ID_GPG_MAIN_KEY_MANAGEMENT,	_T("Ctrl+G"),	_T("̊Ǘ(&G)"));
+//	m_acceleratorTable.AddAccelerator(_T("GPG"),				ID_GPG,						_T("Ctrl+G"),	_T("̊Ǘ(&G)"));
+	m_acceleratorTable.AddAccelerator(_T("GPGDecode"),			ID_GPG_DEC,					_T("Ctrl+D"),	_T("(&D)"));
+
+	// setting
+	m_acceleratorTable.AddAccelerator(_T("ShowCommonSetting"),	ID_SETTING_GENERAL,			_T("Ctrl+F9"),	_T("ʓIȐݒ(&V)..."));
+	m_acceleratorTable.AddAccelerator(_T("ShowAccountSetting"),	ID_SETTING_ACCOUNT,			_T("Ctrl+F10"),	_T("AJEgݒ(&S)..."));
+//	m_acceleratorTable.AddAccelerator(_T("ShowSetting"),		ID_SETTING,					_T(""),			_T("ݒEBhE\"));
+	m_acceleratorTable.AddAccelerator(_T("ShowFilterSetting"),	ID_SETTING_FILTER,			_T("Ctrl+F11"),	_T("U蕪ݒ(&F)..."));
+	m_acceleratorTable.AddAccelerator(_T("CreateNewAccount"),	ID_SETTING_NEW_ACCOUNT,		_T(""),			_T("VKAJEg(&N)"));
+	m_acceleratorTable.AddAccelerator(_T("ShowAddressBook"),	ID_ADDRESS,					_T("Ctrl+B"),	_T("AhX̒ǉƍ폜(&A)..."));
+
+	// show info
+//	m_acceleratorTable.AddAccelerator(_T("ShowInfo"),			ID_INFO,					_T("Ctrl+H"),	_T("\"));
+	m_acceleratorTable.AddAccelerator(_T("ShowHeader"),			ID_DISPLAY_HEADER,			_T("Ctrl+H"),	_T("wb_[̕\(&H)..."));
+	m_acceleratorTable.AddAccelerator(_T("ShowRowMail"),		ID_DISPLAY_RAW_MAIL,		_T("Ctrl+R"),	_T("Õ[\(&R)..."));
+
+	// view
+	m_acceleratorTable.AddAccelerator(_T("SwitchView"),			ID_SWITCH_VIEW,				_T("Ctrl+O"),	_T("r[̃tH[JX؂ւ"));
+	m_acceleratorTable.AddAccelerator(_T("ScrollMail"),			ID_SCROLL_MAIL,				_T(""),			_T("[XN["));
+
+	////////////////// Summary View ////////////////////////////////////////////////////////////////////////////////////////
+	m_acceleratorTable.AddAccelerator(_T("CheckDeleteMark"),	ID_CHECK_DELETE_MARK,		_T("d"),		_T("폜}[N"));
+	m_acceleratorTable.AddAccelerator(_T("UncheckDeleteMark"),	ID_UNCHECK_DELETE_MARK,		_T("u"),		_T("폜}[N"));
+	m_acceleratorTable.AddAccelerator(_T("ExecuteDeleteMark"),	ID_EXECUTE_DELETE_MARK,		_T("x"),		_T("폜}[Nt[폜"));
+	m_acceleratorTable.AddAccelerator(_T("SelectTopMail"),		ID_SELECT_TOP_MAIL,			_T(""),			_T("ԏ̃[I"));
+	m_acceleratorTable.AddAccelerator(_T("SelectBottomMail"),	ID_SELECT_BOTTOM_MAIL,		_T(""),			_T("ԉ̃[I"));
+//	m_acceleratorTable.AddAccelerator(_T("RebuildSummary"),		ID_SUMMARYVIEW_REBUILD,		_T(""),			_T("T}[̍č\z"));
+	m_acceleratorTable.AddAccelerator(_T("NextMail"),			ID_NEXT_MAIL,				_T("Ctrl+N"),	_T("̃[I"));
+	m_acceleratorTable.AddAccelerator(_T("PrevMail"),			ID_PREV_MAIL,				_T("Ctrl+P"),	_T("Õ[I"));
+	m_acceleratorTable.AddAccelerator(_T("NextUnreadMail"),		ID_NEXT_UNREAD_MAIL,		_T("n"),		_T("̖ǃ[I"));
+
+	////////////////// Folder View ////////////////////////////////////////////////////////////////////////////////////////
+	m_acceleratorTable.AddAccelerator(_T("NextFolder"),			ID_NEXT_FOLDER,				_T(""),			_T("̃tH_[\"));
+	m_acceleratorTable.AddAccelerator(_T("PrevFolder"),			ID_PREV_FOLDER,				_T(""),			_T("ÕtH_[\"));
+
+	////////////////// Account View ////////////////////////////////////////////////////////////////////////////////////////
+	m_acceleratorTable.AddAccelerator(_T("NextAccount"),		ID_NEXT_ACCOUNT,			_T(""),			_T("̃AJEg\"));
+	m_acceleratorTable.AddAccelerator(_T("PrevAccount"),		ID_PREV_ACCOUNT,			_T(""),			_T("ÕAJEg\"));
+
+	////////////////// MultiPart View ////////////////////////////////////////////////////////////////////////////////////////
+//		case VK_RETURN: // Ytt@C̏ꍇN			ExecuteFile();
+//		case 'n':			SelectNext();
+//		case 'p':			SelectPrev();
+
+	////////////////// Text View ////////////////////////////////////////////////////////////////////////////////////////
+	m_acceleratorTable.AddAccelerator(_T("PageUp"),				ID_PAGE_UP,					_T("b"),		_T("1y[WɃXN["));
+	m_acceleratorTable.AddAccelerator(_T("PageDown"),			ID_PAGE_DOWN,				_T(""),			_T("1y[WɃXN["));
+	m_acceleratorTable.AddAccelerator(_T("ScrollAndNextUnread"),ID_SCROLL_AND_NEXT_UNREAD,	_T("Space"),	_T("XN[ & ̖ǃ[I"));
+//		case '<': // plan to implement
+//		case '>': // plan to implement
+
+	m_acceleratorTable.CreateAcceleratorTable();
+}
