@@ -14,6 +14,7 @@
 #include "TextView.h"
 #include "HeaderView.h"
 #include "NotifyIcon.h"
+#include "AcceleratorTable.h"
 
 #if _MSC_VER > 1000
 #pragma once
@@ -37,17 +38,20 @@ public:
 	//{{AFX_VIRTUAL(CMainFrame)
 	public:
 	virtual BOOL PreCreateWindow(CREATESTRUCT& cs);
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
+	virtual BOOL PreTranslateMessage(MSG* pMsg);
 	virtual BOOL OnCmdMsg(UINT nID, int nCode, void* pExtra, AFX_CMDHANDLERINFO* pHandlerInfo);
-// end
 	protected:
 	virtual BOOL OnCreateClient(LPCREATESTRUCT lpcs, CCreateContext* pContext);
 	virtual LRESULT WindowProc(UINT message, WPARAM wParam, LPARAM lParam);
+	virtual BOOL OnCommand(WPARAM wParam, LPARAM lParam);
 	//}}AFX_VIRTUAL
 
 // Cve[V
 public:
+	bool SelectNextUnreadFolder();
+	void SetAcceleratorTargetWindow();
+	void LoadDefaultAccelerator();
+	void LoadAccelerator();
 	void HideHeaderView(BOOL b);
 	void StopTaskTrayAnimation();
 	void StartTaskTrayAnimation();
@@ -58,10 +62,10 @@ public:
 	void GetStatusBarProgress(int &current, int &upper);
 	CString GetStatusBarText();
 	void SetStatusBarProgress(int current, int upper);
-	void UpdateButton(BOOL b, CString account);
+	void UpdateButton1(BOOL b, CString account);
+	void UpdateButton2(BOOL b);
 	void HideMultiPartView(BOOL b);
 	void ReArrangeSplit();
-	void SwitchView();
 	CSummaryView* m_pListV;
 	CAccountView* m_pAcntV;
 	CFolderView* m_pTreeV;
@@ -75,7 +79,6 @@ public:
 	CSplitterWndEx m_split_header_text;
 	BOOL m_flag;
 	CProgressCtrl m_progress;
-	BOOL Char(UINT nChar);
 	void SetStatusBarText(int pane, LPCSTR buf);
 	BOOL CreateToolbar();
 	virtual ~CMainFrame();
@@ -84,6 +87,9 @@ public:
 	virtual void Dump(CDumpContext& dc) const;
 #endif
 private:
+	const std::string FindUnreadFolderPath(const std::vector<std::string>& folderList, const std::string& startFolderPath);
+	bool CreateFolderList(const std::string& path, std::vector<std::string>& folderList);
+	CAcceleratorTable m_acceleratorTable;
 	HINSTANCE m_hRichEdit20;
 	int m_tasktray_animation_num;
 	CNotifyIcon m_notifyIcon;
@@ -92,10 +98,7 @@ private:
 protected:  // Rg[ o[po
 	CToolBar    m_wndToolBar;
 	CStatusBar  m_wndStatusBar;
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
 	CStringArray m_template_array;
-// end
 
 // ꂽbZ[W }bv֐
 protected:
@@ -122,12 +125,7 @@ protected:
 	afx_msg void OnInfo();
 	afx_msg void OnUpdateInfo(CCmdUI* pCmdUI);
 	afx_msg void OnUpdateSetting(CCmdUI* pCmdUI);
-	afx_msg void OnToolbarDropDown(NMTOOLBAR* pnmh, LRESULT* plRes);
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
-//	afx_msg void OnReplyQuotation();
-//	afx_msg void OnReplyNoQuotation();
-// end
+	afx_msg BOOL OnToolbarDropDown(NMHDR *pNMHDR, LRESULT* plRes);
 	afx_msg void OnTimer(UINT nIDEvent);
 	afx_msg void OnSettingGeneral();
 	afx_msg void OnSettingAccount();
@@ -137,6 +135,8 @@ protected:
 	afx_msg void OnSettingNewAccount();
 	afx_msg void OnTransferQuotation();
 	afx_msg void OnGpgKeyManagement();
+	afx_msg void OnSwitchView();
+	afx_msg void OnScrollMail();
 	afx_msg void OnClose();
 	afx_msg BOOL OnCopyData(CWnd* pWnd, COPYDATASTRUCT* pCopyDataStruct);
 	afx_msg void OnSysCommand(UINT nID, LPARAM lParam);
