@@ -359,6 +359,113 @@ void CMimeEncode::EncodeHeader(CString& org)
 	CString tmp2;
 	CString tmp3;
 	unsigned char *out;
+
+	CStringArray array_org;
+	CStringArray array_dst;
+	CStringArray array_tmp;
+	CString buf;
+	CString buf2;
+
+	if(org.IsEmpty())
+		return;
+
+	array_org.RemoveAll();
+	array_dst.RemoveAll();
+	array_tmp.RemoveAll();
+	g_cstr2cstra(org, array_org, "\r\n");
+
+	i = 0;
+	while(i < array_org.GetSize()){
+		buf = array_org.GetAt(i);
+		buf.TrimRight("\r\n");
+		array_tmp.RemoveAll();
+		j = 0;
+		while(j < buf.GetLength()){
+			// search non-ascii char
+			if(buf[j]==0x1b && buf[j+1]==0x24 && buf[j+2]==0x42){
+				istart=j;
+				j+=3;
+				for(;j<buf.GetLength()-2 && (buf[j]!=0x1b || buf[j+1]!=0x28 || buf[j+2]!=0x42);j++);
+				j+=3;
+				// pick out non-ascii char
+				tmp=buf.Mid(istart, j-istart);
+				// need to confirm whether or not length of line is less than 57.
+				if(!buf2.IsEmpty()){
+					buf2.TrimRight("\r\n");
+					buf2+="\r\n";
+					while(buf2.GetLength() > 76){
+						array_tmp.Add(buf2.Left(77)+"\r\n");
+						buf2 = buf2.Mid(77);
+					}
+					array_tmp.Add(buf2);
+					buf2.Empty();
+				}
+				while(tmp.GetLength() > 40){
+					tmp3 = tmp.Left(41);//
+					//////////////////////////////////////////////////////////
+					if(tmp3[0] != 0x1b){
+						tmp3 = "\x1b\x24\x42"+tmp3;
+					}
+					tmp3 += "\x1b\x28\x42";
+					//////////////////////////////////////////////////////////
+					tmp = tmp.Mid(41);//
+					out = (unsigned char *)tmp2.GetBuffer(tmp3.GetLength()*3);
+					to64frombits(out, (unsigned char *)tmp3.GetBuffer(0), tmp3.GetLength());
+					tmp2.ReleaseBuffer();
+					tmp2 = "=?ISO-2022-JP?B?"+tmp2+"?=\r\n";
+					array_tmp.Add(tmp2);
+					tmp2.Empty();
+					tmp3.Empty();
+				}
+				///////////////////////////////////////////////////
+				if(tmp[0] != 0x1b){
+					tmp = "\x1b\x24\x42"+tmp;
+				}
+				//////////////////////////////////////////////////////
+				out = (unsigned char *)tmp2.GetBuffer(tmp.GetLength()*3);
+				to64frombits(out, (unsigned char *)tmp.GetBuffer(0), tmp.GetLength());
+				tmp2.ReleaseBuffer();
+				tmp2 = "=?ISO-2022-JP?B?"+tmp2+"?=";
+				tmp2.TrimRight("\r\n");
+				tmp2+="\r\n";
+				array_tmp.Add(tmp2);
+				tmp2.Empty();
+			}else{
+				buf2+=buf[j];
+				j++;
+			}
+		}
+
+		// need to confirm length of line
+		if(!buf2.IsEmpty() && (buf2 != "\r\n")){
+			buf2.TrimRight("\r\n"); 
+			buf2+="\r\n";
+			array_tmp.Add(buf2); buf2.Empty();
+		}
+
+		j = 1;
+		while(j < array_tmp.GetSize()){
+			array_tmp.SetAt(j, " "+array_tmp.GetAt(j));
+			j++;
+		}
+
+		j = 0;
+		while(j < array_tmp.GetSize()){
+			array_dst.Add(array_tmp.GetAt(j));
+			j++;
+		}
+		i++;
+	}
+	g_cstra2cstr(array_dst, org, g_cstra_getsize(array_dst));
+
+/*	int i = 0;
+	int j = 0;
+	int istart;
+	CString dst;
+	CString tmp;
+	CString tmp2;
+	CString tmp3;
+	unsigned char *out;
 //	const int size = 30;
 //	BOOL folding_space = FALSE;
 
@@ -447,6 +554,7 @@ void CMimeEncode::EncodeHeader(CString& org)
 		i++;
 	}
 	g_cstra2cstr(array_dst, org, g_cstra_getsize(array_dst));
+	*/
 }
 
 BOOL CMimeEncode::EncodeBase64FromFile(CString path, CString &buf)
@@ -701,8 +809,6 @@ CString CMimeEncode::GetBoundaryChar()
 
 }
 
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
 void CMimeEncode::AddTo(CString address)
 {
 	if(!m_data.m_to.IsEmpty() && !address.IsEmpty()){
@@ -729,4 +835,3 @@ void CMimeEncode::AddBcc(CString address)
 		m_data.m_bcc = address;
 	}
 }
-// end
\ No newline at end of file
