@@ -16,10 +16,7 @@
 #include "direct.h" // for _mkdir
 #include "quoted-printable.h"
 #include "base64.h"
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
 #include "skin.h"
-// end
 
 #ifdef _DEBUG
 #define new DEBUG_NEW
@@ -27,10 +24,7 @@
 static char THIS_FILE[] = __FILE__;
 #endif
 
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
 #define MULTIPARTVIEW_BACKGROUND_FILENAME _T("\\skin\\MultiPartViewBk.bmp")
-// end
 
 /////////////////////////////////////////////////////////////////////////////
 // CMultiPartView
@@ -52,7 +46,6 @@ BEGIN_MESSAGE_MAP(CMultiPartView, CListView)
 	//{{AFX_MSG_MAP(CMultiPartView)
 	ON_NOTIFY_REFLECT(LVN_ITEMCHANGED, OnItemchanged)
 	ON_NOTIFY_REFLECT(NM_RCLICK, OnRclick)
-	ON_WM_CHAR()
 	ON_WM_SIZE()
 	ON_NOTIFY_REFLECT(NM_DBLCLK, OnDblclk)
 	ON_COMMAND(ID_MULTIPART_SAVE2FILE, OnMultipartSave2file)
@@ -140,8 +133,6 @@ void CMultiPartView::OnInitialUpdate()
 	// setting system icon image.
 	m_image.Create(16, 16, ILC_COLORDDB | ILC_MASK, 1, 100);
 
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
 	// skin.ini
 	CString strBackgroundFilePath;
 	if(app->m_skin.getMultiPartViewBackBmp() == ""){
@@ -150,7 +141,6 @@ void CMultiPartView::OnInitialUpdate()
 		strBackgroundFilePath = app->m_skin.getSkinIniPath() + "\\" + app->m_skin.getMultiPartViewBackBmp();
 	}
 	SetBkImage(strBackgroundFilePath);
-// end
 }
 
 void CMultiPartView::OnItemchanged(NMHDR* pNMHDR, LRESULT* pResult) 
@@ -179,30 +169,6 @@ void CMultiPartView::OnRclick(NMHDR* pNMHDR, LRESULT* pResult)
 	*pResult = 0;
 }
 
-void CMultiPartView::OnChar(UINT nChar, UINT nRepCnt, UINT nFlags) 
-{
-	CPochyApp* app = (CPochyApp*)AfxGetApp();
-	CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;
-
-	if(mf->Char(nChar))
-		return;
-
-	switch(nChar){
-		case VK_RETURN: // may be excute attached file
-//			ExecuteFile();
-			break;
-		case 'n':
-//			SelectNext();
-			break;
-		case 'p':
-//			SelectPrev();
-			break;
-		default:
-			break;
-	}	
-	CListView::OnChar(nChar, nRepCnt, nFlags);
-}
-
 void CMultiPartView::ReArrange()
 {
 	int i,width;
@@ -267,7 +233,7 @@ void CMultiPartView::ExecuteFile()
 				}
 				fwrite(out, sizeof(char), len, file);
 				fclose(file);
-				delete out;
+				delete[] out;
 			}
 			// quoted-pritable
 			else if(tv->GetCurrentCTE() == QUOTED_PRINTABLE){
@@ -282,7 +248,7 @@ void CMultiPartView::ExecuteFile()
 				}
 				fwrite(out2, sizeof(char), len, file);
 				fclose(file);
-				delete out2;
+				delete[] out2;
 			}else{
 				if(tv->GetCurrentCTE() == SEVEN_BIT || tv->GetCurrentCTE() == EIGHT_BIT){
 					CCodeConvert cc(body);
@@ -302,15 +268,15 @@ void CMultiPartView::ExecuteFile()
 				from64tobits(out_base64, in_base64, strlen(in_base64));
 				body.Empty();
 				body = out_base64;
-				delete out_base64;
+				delete[] out_base64;
 			}
 			else if(QUOTED_PRINTABLE == tv->GetCurrentCTE()){
 				char* in_qp = body.GetBuffer(0);
-				char* out_qp = new char[body.GetLength()];
+				char* out_qp = new char[body.GetLength() + 1];
 				fromQPtobits(out_qp, in_qp, strlen(in_qp));
 				body.Empty();
 				body = out_qp;
-				delete out_qp;
+				delete[] out_qp;
 			}
 			msg_id = tv->m_md.m_hi.GetMsgID();
 			msg_id = g_ma(msg_id);
@@ -327,7 +293,15 @@ void CMultiPartView::ExecuteFile()
 			fwrite(body.GetBuffer(0), sizeof(char), body.GetLength(), file);
 			fclose(file);
 			// open file
-			ShellExecute(NULL, "open", app->m_app_path+"\\temp\\"+file_name, NULL, NULL, SW_SHOW);
+			CString strBrowserPath = app->GetProfileString(_T("Customize"), _T("BrowserPath"), _T(""));
+			if (strBrowserPath != _T(""))
+			{
+				ShellExecute(NULL, NULL, strBrowserPath, app->m_app_path+"\\temp\\"+file_name, NULL, SW_SHOW);
+			}
+			else
+			{
+				ShellExecute(NULL, "open", app->m_app_path+"\\temp\\"+file_name, NULL, NULL, SW_SHOW);
+			}
 		}
 		// text/plain
 		else if(g_cstr_compare(tv->m_md.GetContentType(m_index), "Text/Plain")){
@@ -337,15 +311,15 @@ void CMultiPartView::ExecuteFile()
 				from64tobits(out_base64, in_base64, strlen(in_base64));
 				body.Empty();
 				body = out_base64;
-				delete out_base64;
+				delete[] out_base64;
 			}
 			else if(QUOTED_PRINTABLE == tv->GetCurrentCTE()){
 				char* in_qp = body.GetBuffer(0);
-				char* out_qp = new char[body.GetLength()];
+				char* out_qp = new char[body.GetLength() + 1];
 				fromQPtobits(out_qp, in_qp, strlen(in_qp));
 				body.Empty();
 				body = out_qp;
-				delete out_qp;
+				delete[] out_qp;
 			}
 			msg_id = tv->m_md.m_hi.GetMsgID();
 			msg_id = g_ma(msg_id);
@@ -376,15 +350,15 @@ void CMultiPartView::ExecuteFile()
 				from64tobits(out_base64, in_base64, strlen(in_base64));
 				body.Empty();
 				body = out_base64;
-				delete out_base64;
+				delete[] out_base64;
 			}
 			else if(QUOTED_PRINTABLE == tv->GetCurrentCTE()){
 				char* in_qp = body.GetBuffer(0);
-				char* out_qp = new char[body.GetLength()];
+				char* out_qp = new char[body.GetLength() + 1];
 				fromQPtobits(out_qp, in_qp, strlen(in_qp));
 				body.Empty();
 				body = out_qp;
-				delete out_qp;
+				delete[] out_qp;
 			}
 			msg_id = tv->m_md.m_hi.GetMsgID();
 			msg_id = g_ma(msg_id);
