@@ -6,19 +6,13 @@
 #endif // _MSC_VER > 1000
 // MultiPartView.h : wb_[ t@C
 //
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
 #include "BitmapListView.h"
-// end
 
 /////////////////////////////////////////////////////////////////////////////
 // CMultiPartView r[
 
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
 //class CMultiPartView : public CListView
 class CMultiPartView : public CBitmapListView
-// end
 {
 protected:
 	CMultiPartView();           // IɎgpveNg RXgN^
@@ -59,7 +53,6 @@ protected:
 	//{{AFX_MSG(CMultiPartView)
 	afx_msg void OnItemchanged(NMHDR* pNMHDR, LRESULT* pResult);
 	afx_msg void OnRclick(NMHDR* pNMHDR, LRESULT* pResult);
-	afx_msg void OnChar(UINT nChar, UINT nRepCnt, UINT nFlags);
 	afx_msg void OnSize(UINT nType, int cx, int cy);
 	afx_msg void OnDblclk(NMHDR* pNMHDR, LRESULT* pResult);
 	afx_msg void OnMultipartSave2file();
