@@ -81,10 +81,8 @@
 #define IDB_DRAG                        204
 #define IDB_SUMMARYVIEW                 207
 #define IDD_SETTING_GENERAL_SKINSELECT  208
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
 #define IDD_MAIN_ADDRESS_CHECK          209
-// end
+#define IDR_MAINFRAME_POPUP_DRAFT       210
 #define IDC_EDIT1                       1000
 #define IDC_EDIT2                       1001
 #define IDC_PROGRESS1                   1002
@@ -92,29 +90,20 @@
 #define IDC_BUTTON1                     1003
 #define IDC_EDIT4                       1003
 #define IDC_GPG_EXPORT                  1003
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
 #define IDC_MAIN_ADDRESS_CHECK_TO_BUTTON 1003
-// end
 #define IDC_LIST1                       1004
 #define IDC_EDIT5                       1004
 #define IDC_BUTTON2                     1005
 #define IDC_ADDR2_LIST1                 1005
 #define IDC_FROM                        1005
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
 #define IDC_MAIN_ADDRESS_CHECK_CC_BUTTON 1005
-// end
 #define IDC_EDIT6                       1006
 #define IDC_BUTTON3                     1006
 #define IDC_ADDR2_DEL2                  1006
 #define IDC_FILTER_REPLACE              1006
 #define IDC_SETTING_ADDRESS             1006
 #define IDC_MAINFRAME_ADDRESSBOOK_DEL   1006
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
 #define IDC_MAIN_ADDRESS_CHECK_BCC_BUTTON 1006
-// end
 #define IDC_COMBO1                      1007
 #define IDC_BUTTON4                     1007
 #define IDC_PASS                        1007
@@ -128,10 +117,7 @@
 #define IDC_SETTING_USERID              1008
 #define IDC_DRAFT_ADDRESSBOOK_DST_LIST  1008
 #define IDC_BUTTON_CC                   1008
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
 #define IDC_MAIN_ADDRESS_CHECK_LIST     1008
-// end
 #define IDC_BUTTON6                     1009
 #define IDC_FILTER_FIELD                1009
 #define IDC_SETTING_BOXNAME             1009
@@ -259,13 +245,7 @@
 #define ID_TEXTVIEW_BROWSER             32808
 #define ID_TEXTVIEW_EDITOR              32809
 #define ID_SAVE_TO_DRAFT                32857
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
-//#define ID_REPLY_QUOTATION              32862
-//#define ID_REPLY_NO_QUOTATION           32863
-//#define ID_TRANSFER_RFC822              32864
 #define ID_REPLY_DEFAULT                32862
-// end
 #define ID_CHANGE_BK_COLOR              32865
 #define ID_CHANGE_TXT_COLOR             32866
 #define ID_HD_TXT_COLOR                 32867
@@ -294,19 +274,31 @@
 #define ID_GPG_MAIN_KEY_MANAGEMENT      32895
 #define ID_GPG_DRAFT_KEY_MANAGEMENT     32896
 #define ID_FOLDERVIEW_CLEAR_TRASH       32897
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
-//#define ID_TRANSFER_ATTACH              32898
-// end
 #define ID_SUMMARYVIEW_DEL              32899
 #define ID_SUMMARYVIEW_REBUILD          32900
 #define ID_SUMMARYVIEW_HEADER_INFO      32901
 #define ID_SUMMARYVIEW_RAWMAIL_INFO     32902
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
+#define ID_SWITCH_VIEW                  32903
+#define ID_SCROLL_MAIL                  32904
+#define ID_CHECK_DELETE_MARK            32905
+#define ID_UNCHECK_DELETE_MARK          32906
+#define ID_EXECUTE_DELETE_MARK          32907
+#define ID_SELECT_TOP_MAIL              32908
+#define ID_SELECT_BOTTOM_MAIL           32909
+#define ID_NEXT_FOLDER                  32910
+#define ID_PREV_FOLDER                  32911
+#define ID_ADDRESS_COMPLEMENT           32912
+#define ID_NEXT_ACCOUNT                 32913
+#define ID_PREV_ACCOUNT                 32914
+#define ID_NEXT_MAIL                    32915
+#define ID_PREV_MAIL                    32916
+#define ID_NEXT_UNREAD_MAIL             32917
+#define ID_PAGE_UP                      32918
+#define ID_PAGE_DOWN                    32919
+#define ID_SCROLL_AND_NEXT_UNREAD       32920
+#define ID_DRAFT_DEFAULT                32921
 #define ID_DYNAMIC_DROP_DOWN_MENU_START 40000
 #define ID_DYNAMIC_DROP_DOWN_MENU_END   41000
-// end
 #define ID_INDICATOR_TEXT               59143
 #define ID_INDICATOR_PROGRESS           59144
 #define ID_INDICATOR_FOLDER             59145
@@ -316,13 +308,8 @@
 #ifdef APSTUDIO_INVOKED
 #ifndef APSTUDIO_READONLY_SYMBOLS
 #define _APS_3D_CONTROLS                     1
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
-//#define _APS_NEXT_RESOURCE_VALUE        208
-//#define _APS_NEXT_COMMAND_VALUE         32901
-#define _APS_NEXT_RESOURCE_VALUE        210
-#define _APS_NEXT_COMMAND_VALUE         32902
-// end
+#define _APS_NEXT_RESOURCE_VALUE        211
+#define _APS_NEXT_COMMAND_VALUE         32922
 #define _APS_NEXT_CONTROL_VALUE         1098
 #define _APS_NEXT_SYMED_VALUE           101
 #endif
