@@ -71,19 +71,6 @@ UINT SendMail(LPVOID pParam)
 	pop_before_smtp = GetPrivateProfileInt("smtp", "pop_before_smtp", 0, path);
 	if(pop_before_smtp){
 		try{
-			CString message;
-			CString pop_addr;
-			GetPrivateProfileString("pop", "server_addr", "", pop_addr.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
-			CString pop_port;
-			GetPrivateProfileString("pop", "port", "", pop_port.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
-
-			if(INVALID_SOCKET == PopSocket.Connect6(pop_addr.GetBuffer(0), pop_port.GetBuffer(0))){
-				throw "cannot establish connection";
-			}
-			PopSocket.SockRead(buf);
-			df->m_send_dlg->m_status.SetWindowText(buf);
-			buf.Empty();
-
 			// get user name from ini file.
 			CString pop_user;
 			GetPrivateProfileString("pop", "user", "", pop_user.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
@@ -93,6 +80,17 @@ UINT SendMail(LPVOID pParam)
 			CString pop_pass;
 			GetPrivateProfileString("pop", "pass", "", pop_pass.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
 			pop_pass.ReleaseBuffer();
+
+			CString isSecreted;
+			GetPrivateProfileString("secreted", "pass_secreted", "", isSecreted.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+			isSecreted.ReleaseBuffer();
+			//if pass_secreted equals "yes" then pass decode.
+			if(!isSecreted.IsEmpty()) {	
+				if(isSecreted.Compare("yes") == 0) {
+					pop_pass = g_simple_decode(pop_pass);
+				}
+			}
+
 			if(pop_pass.IsEmpty() && !mf->m_pAcntV->GetAccountPopPass(df->m_account).IsEmpty()){
 				pop_pass = mf->m_pAcntV->GetAccountPopPass(df->m_account);
 			}else if(pop_pass.IsEmpty() && mf->m_pAcntV->GetAccountPopPass(df->m_account).IsEmpty()){
@@ -106,8 +104,25 @@ UINT SendMail(LPVOID pParam)
 				}
 			}
 
-			CString md5_in;
+			CString message;
+			CString pop_addr;
+			
+			GetPrivateProfileString("pop", "server_addr", "", pop_addr.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+			CString pop_port;
+			GetPrivateProfileString("pop", "port", "", pop_port.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+
+			if(INVALID_SOCKET == PopSocket.Connect6(pop_addr.GetBuffer(0), pop_port.GetBuffer(0))){
+				throw "cannot establish connection";
+			}
+			PopSocket.SockRead(buf);
+			df->m_send_dlg->m_status.SetWindowText(buf);
+
+			// for apop
+			CString md5_in; 
 			CString md5_out;
+
+			md5_in = buf.Mid(buf.Find("<"), buf.Find(">")-buf.Find("<")+1);
+			buf.Empty();
 			CString apop;
 			if(GetPrivateProfileInt("pop", "apop", 0, path)){
 				// if using apop, below is done.
@@ -178,6 +193,28 @@ UINT SendMail(LPVOID pParam)
 	}
 
 	try{
+		if(GetPrivateProfileInt("smtp", "auth", 0, path)){
+			// get auth id from ini file.
+			GetPrivateProfileString("smtp", "auth_id", "", smtp_auth_id.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+			smtp_auth_id.ReleaseBuffer();
+			
+			// get auth password from ini file.
+			GetPrivateProfileString("smtp", "auth_pass", "", smtp_auth_pass.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+			smtp_auth_pass.ReleaseBuffer();
+			smtp_auth_pass = g_simple_decode(smtp_auth_pass);
+			if(smtp_auth_pass.IsEmpty() && !mf->m_pAcntV->GetSmtpAuthPass(df->m_account).IsEmpty()){
+				smtp_auth_pass = mf->m_pAcntV->GetSmtpAuthPass(df->m_account);
+			}else if(smtp_auth_pass.IsEmpty() && mf->m_pAcntV->GetSmtpAuthPass(df->m_account).IsEmpty()){
+				// if getting no password from ini file, then show dialog for inputing password.
+				CPassPhraseDlg passDlg(df);
+				if(IDOK == passDlg.DoModal()){
+					smtp_auth_pass = passDlg.GetPass();
+					mf->m_pAcntV->SetSmtpAuthPass(df->m_account, smtp_auth_pass);
+				}else{
+					throw "";
+				}
+			}
+		}
 		// prepare for smtp
 		GetPrivateProfileString("smtp", "server_addr", "", smtp_addr.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
 		GetPrivateProfileString("smtp", "port", "", smtp_port.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
@@ -197,10 +234,6 @@ UINT SendMail(LPVOID pParam)
 		buf.Empty();
 	//-------------- helo ------------------
 		if(GetPrivateProfileInt("smtp", "auth", 0, path)){
-			GetPrivateProfileString("smtp", "auth_id", "", smtp_auth_id.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
-			smtp_auth_id.ReleaseBuffer();
-			GetPrivateProfileString("smtp", "auth_pass", "", smtp_auth_pass.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
-			smtp_auth_pass.ReleaseBuffer();
 			if(!Smtp.Ehlo(smtp_auth_id, smtp_auth_pass)){
 				throw "smtp auth error";
 			}
