@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2003 chik, s.hiranaka
+ * Copyright (C) 2002-2003 chik, hiranaka
  * For license terms, see the file COPYING in this directory.
  */
 
@@ -11,6 +11,7 @@
 #include "SettingGeneralDlg.h"
 #include "SettingGeneralAppearanceDlg.h"
 #include "SettingGeneralOtherDlg.h"
+#include "SettingGeneralSkinSelectDlg.h"
 #include "MainFrm.h"
 
 #ifdef _DEBUG
@@ -63,16 +64,25 @@ BOOL CSettingGeneralDlg::OnInitDialog()
 	item.pszText = "̑";
 	m_tab.InsertItem(1, &item);
 
+	item.pszText = "XLI";
+	m_tab.InsertItem(2, &item);
+
 	// ^uRg[eEBhEƂĊe^uy[W쐬
 	m_appearance_dlg.Create(IDD_SETTING_GENERAL_APPEARANCE, &m_tab);
 	m_other_dlg.Create(IDD_SETTING_GENERAL_OTHER, &m_tab);
+	m_skinselect_dlg.Create(IDD_SETTING_GENERAL_SKINSELECT, &m_tab);
 
 	//\Ԃ̐ݒ
 	m_appearance_dlg.SetWindowPos(&wndTop, 2, 20, 0, 0, SWP_NOSIZE | SWP_SHOWWINDOW);
 	m_other_dlg.SetWindowPos(&wndTop, 2, 20, 0, 0, SWP_NOSIZE | SWP_SHOWWINDOW);
+	m_skinselect_dlg.SetWindowPos(&wndTop, 2, 20, 0, 0, SWP_NOSIZE | SWP_SHOWWINDOW);
+
+	CPochyApp* app = (CPochyApp*)AfxGetApp();
+	m_skinselect_dlg.m_skin_path.SetWindowText(app->m_skin.getSkinIniFile());
 
 	m_appearance_dlg.ShowWindow(SW_SHOW);
 	m_other_dlg.ShowWindow(SW_HIDE);
+	m_skinselect_dlg.ShowWindow(SW_HIDE);
 
 	return TRUE;  // Rg[ɃtH[JXݒ肵ȂƂA߂l TRUE ƂȂ܂
 	              // O: OCX vpeB y[W̖߂l FALSE ƂȂ܂
@@ -86,10 +96,17 @@ void CSettingGeneralDlg::OnSelchangeTab(NMHDR* pNMHDR, LRESULT* pResult)
 	case 0:
 		m_appearance_dlg.ShowWindow(SW_SHOW);
 		m_other_dlg.ShowWindow(SW_HIDE);
+		m_skinselect_dlg.ShowWindow(SW_HIDE);
 		break;
 	case 1:
 		m_appearance_dlg.ShowWindow(SW_HIDE);
 		m_other_dlg.ShowWindow(SW_SHOW);
+		m_skinselect_dlg.ShowWindow(SW_HIDE);
+		break;
+	case 2:
+		m_appearance_dlg.ShowWindow(SW_HIDE);
+		m_other_dlg.ShowWindow(SW_HIDE);
+		m_skinselect_dlg.ShowWindow(SW_SHOW);
 		break;
 	}
 
@@ -199,5 +216,16 @@ void CSettingGeneralDlg::OnOK()
 	int nTaskTrayOnly = m_other_dlg.m_checkTaskTrayOnly.GetCheck();
 	app->WriteProfileInt(_T("TaskTray"), _T("TaskTrayOnly"), nTaskTrayOnly);
 
+	// ǐ\ݒ̕ۑ
+	int nShowUnreadCount = m_other_dlg.m_checkShowUnreadCount.GetCheck();
+	app->WriteProfileInt(_T("FolderView"), _T("ShowUnreadCount"), nShowUnreadCount);
+	mf->m_pTreeV->SetShowUnreadCount(nShowUnreadCount == 1);
+
+	// XLI̐ݒXV
+	CString sbuf;
+	m_skinselect_dlg.m_skin_path.GetWindowText(sbuf);
+	app->WriteProfileString("Skin", "Path", sbuf);
+	sbuf.Empty();
+
 	CDialog::OnOK();
 }
