@@ -26,17 +26,10 @@ CSkin::CSkin()
 	m_summarryViewBackBmp = "";
 	m_folderViewBackBmp = "";
 	m_textViewBackBmp = "";
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
-//	m_mailEditViewBackBmp = "";
 	m_maileditViewBackBmp = "";
-// end
 	m_headerViewBackBmp = "";
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
  	m_attachedfileViewBackBmp = "";
  	m_multipartViewBackBmp = "";
-// end
 	m_toolbarDraftIcons = "";
 	m_toolbarMainIcons = "";
 	m_treeViewIcons = "";
@@ -126,11 +119,7 @@ BOOL CSkin::LoadSkinProfile(char *skinIniFile)
 					   >> buf.GetBuffer(0);
 				cFStrm >> std::setw( 1024 )
 					   >> skinfilename;
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
-//				m_mailEditViewBackBmp = skinfilename;
 				m_maileditViewBackBmp = skinfilename;
-// end
 			}
 			else if(buf.Find("[HeaderViewBackBmp]") != -1) {
 				// HeaderViewBk.bmp
@@ -141,10 +130,7 @@ BOOL CSkin::LoadSkinProfile(char *skinIniFile)
 				cFStrm >> std::setw( 1024 )
 					   >> skinfilename;
 				m_headerViewBackBmp = skinfilename;
-			}
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
-			else if(buf.Find("[AttachedFileViewBackBmp]") != -1) {
+			}else if(buf.Find("[AttachedFileViewBackBmp]") != -1) {
 				// AttacheFileViewBk.bmp
 				cFStrm >> std::setw( 1024 )
 					   >> buf.GetBuffer(0);
@@ -164,7 +150,6 @@ BOOL CSkin::LoadSkinProfile(char *skinIniFile)
 					   >> skinfilename;
 				m_multipartViewBackBmp = skinfilename;
 			}
-// end
 			else if(buf.Find("[ToolbarDraftIcons]") != -1) {
 				cFStrm >> std::setw( 1024 )
 					   >> buf.GetBuffer(0);
@@ -237,24 +222,19 @@ CString CSkin::getTextViewBackBmp() {
 	return m_textViewBackBmp;
 }
 CString CSkin::getMailEditViewBackBmp() {
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
-//	return m_mailEditViewBackBmp;
 	return m_maileditViewBackBmp;
-// end
 }
 CString CSkin::getHeaderViewBackBmp() {
 	return m_headerViewBackBmp;
 }
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
+
 CString CSkin::getAttachedFileViewBackBmp() {
 	return m_attachedfileViewBackBmp;
 }
 CString CSkin::getMultiPartViewBackBmp() {
 	return m_multipartViewBackBmp;
 }
-// end
+
 CString CSkin::getToolbarDraftIcons() {
 	return m_toolbarDraftIcons;
 }
