@@ -21,7 +21,10 @@
 
 #include <afxrich.h>
 #include <stdio.h>
+#pragma warning (disable : 4786)
+#pragma warning (push, 1)
 #include <fstream>
+#pragma warning (pop)
 
 //{{AFX_INSERT_LOCATION}}
 // Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B
