@@ -30,25 +30,22 @@ CStrTok::~CStrTok()
 
 }
 
-CString CStrTok::Tokenize(char *in, char *delimiter)
+const char* CStrTok::Tokenize(char *in, char *delimiter)
 {
-	CString out;
 	char *start;
 	char *end;
 
-	if(in != NULL) m_buf = in;
-	start = m_buf.GetBuffer(0);
+	if(in != NULL) m_pStart = in;
+	start = m_pStart;
 
 	end = strstr(start, delimiter);
 	if(end == NULL)
 	{
-		out = start;
-		m_buf = start+strlen(start);
-		return out;
+		m_pStart = start+strlen(start);
+		return start;
 	}
 	else *end ='\0';
 
-	out = start;
-	m_buf = end+1;
-	return out;
+	m_pStart = end+1;
+	return start;
 }
