@@ -12,12 +12,12 @@
 class CStrTok  
 {
 public:
-	CString Tokenize(char *in, char *demilitar);
+	const char* Tokenize(char *in, char *demilitar);
 	CStrTok();
 	virtual ~CStrTok();
 
 private:
-	CString m_buf;
+	char* m_pStart;
 };
 
 #endif // !defined(AFX_STRTOK_H__15123621_ECD2_11D5_8C76_444553540000__INCLUDED_)
