@@ -71,7 +71,6 @@ CSummaryView::~CSummaryView()
 BEGIN_MESSAGE_MAP(CSummaryView, CBitmapListView)
 	//{{AFX_MSG_MAP(CSummaryView)
 	ON_NOTIFY_REFLECT(LVN_GETDISPINFO, OnGetdispinfo)
-	ON_WM_CHAR()
 	ON_NOTIFY_REFLECT(NM_DBLCLK, OnDblclk)
 	ON_WM_KEYDOWN()
 	ON_WM_SETFOCUS()
@@ -85,6 +84,9 @@ BEGIN_MESSAGE_MAP(CSummaryView, CBitmapListView)
 	ON_COMMAND(ID_SUMMARYVIEW_REBUILD, OnPopupRebuild)
 	ON_WM_KILLFOCUS()
 	ON_WM_MEASUREITEM_REFLECT()
+	ON_COMMAND(ID_NEXT_MAIL, OnNextMail)
+	ON_COMMAND(ID_PREV_MAIL, OnPrevMail)
+	ON_COMMAND(ID_NEXT_UNREAD_MAIL, OnNextUnreadMail)
 	//}}AFX_MSG_MAP
 END_MESSAGE_MAP()
 
@@ -176,23 +178,11 @@ void CSummaryView::OnInitialUpdate()
 	// T}[r[̔wi摜ݒ
 //	CString strBackgroundFilePath = app->m_app_path + SUMMARYVIEW_BACKGROUND_FILENAME;
 	// skin.ini
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
-//	CPochyApp *pApp =(CPochyApp*)::AfxGetApp();
-// end
 	CString strBackgroundFilePath;
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
-//	if(pApp->m_skin.getSummarryViewBackBmp() == ""){
 	if(app->m_skin.getSummarryViewBackBmp() == ""){
-// end
 		strBackgroundFilePath = app->m_app_path + SUMMARYVIEW_BACKGROUND_FILENAME;
 	}else{
-	// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
-//		strBackgroundFilePath = pApp->m_skin.getSkinIniPath() + "\\" + pApp->m_skin.getSummarryViewBackBmp();
 		strBackgroundFilePath = app->m_skin.getSkinIniPath() + "\\" + app->m_skin.getSummarryViewBackBmp();
-// end
 	}
 	SetBkImage(strBackgroundFilePath);
 
@@ -210,26 +200,26 @@ void CSummaryView::OnGetdispinfo(NMHDR* pNMHDR, LRESULT* pResult)
 	int num = pDispInfo->item.iItem;
 	char *buf;
 
-	if(pDispInfo->item.mask & LVIF_TEXT){
+	if(m_stack_num > 0 && pDispInfo->item.mask & LVIF_TEXT){
 		switch(pDispInfo->item.iSubItem){
 			case 0:
-				buf = m_array_list[m_stack_num-num-1].m_str6.GetBuffer(0);
+				buf = m_array_list[m_stack_num-num-1]->m_str6.GetBuffer(0);
 				lstrcpy(pDispInfo->item.pszText, buf);
 				break;
 			case 1:
-				buf = m_array_list[m_stack_num-num-1].m_str1.GetBuffer(0);
+				buf = m_array_list[m_stack_num-num-1]->m_str1.GetBuffer(0);
 				lstrcpy(pDispInfo->item.pszText, buf);
 				break;					
 			case 2:
-				buf = m_array_list[m_stack_num-num-1].m_str2.GetBuffer(0);
+				buf = m_array_list[m_stack_num-num-1]->m_str2.GetBuffer(0);
 				lstrcpy(pDispInfo->item.pszText, buf);
 				break;					
 			case 3:
-				buf = m_array_list[m_stack_num-num-1].m_str3.GetBuffer(0);
+				buf = m_array_list[m_stack_num-num-1]->m_str3.GetBuffer(0);
 				lstrcpy(pDispInfo->item.pszText, buf);
 				break;
 			case 4:
-				buf = m_array_list[m_stack_num-num-1].m_str4.GetBuffer(0);
+				buf = m_array_list[m_stack_num-num-1]->m_str4.GetBuffer(0);
 				lstrcpy(pDispInfo->item.pszText, buf);
 				break;
 		}
@@ -256,7 +246,6 @@ int CSummaryView::SetStack(CString path)
 {
 	CString tmp;
 	CString message;
-	SLISTSTACK list;
 	CStrTok StrTok;
 
 	CStdioFile ReadFile;
@@ -280,40 +269,22 @@ int CSummaryView::SetStack(CString path)
 	m_array_list.RemoveAll();
 	int n=0;
 	while(ReadFile.ReadString(tmp)){
-		for(int i=1; i<9; i++){
-			switch(i){
-				case 1:
-					list.m_str1 = StrTok.Tokenize(tmp.GetBuffer(0), "\x02");
-					break;
-				case 2:
-					list.m_str2 = StrTok.Tokenize(NULL, "\x02");
-					break;
-				case 3:
-					list.m_str3 = StrTok.Tokenize(NULL, "\x02");
-					break;
-				case 4:
-					list.m_str4 = StrTok.Tokenize(NULL, "\x02");
-					break;
-				case 5:
-					list.m_str5 = StrTok.Tokenize(NULL, "\x02");
-					break;
-				case 6:
-					list.m_str6 = StrTok.Tokenize(NULL, "\x02");
-					if(-1 != list.m_str6.Find("N")){
-						m_unread++;
-					}
-					break;
-				case 7:
-					list.m_str7 = StrTok.Tokenize(NULL, "\x02");
-					break;
-				case 8:
-					list.m_str8 = StrTok.Tokenize(NULL, "\x02");
-					break;
-				case 9:
-					list.m_str9 = StrTok.Tokenize(NULL, "\x02");
-					break;
-			}
+
+		SLISTSTACK* list = new SLISTSTACK;
+
+		list->m_str1 = StrTok.Tokenize(tmp.GetBuffer(0), "\x02");
+		list->m_str2 = StrTok.Tokenize(NULL, "\x02");
+		list->m_str3 = StrTok.Tokenize(NULL, "\x02");
+		list->m_str4 = StrTok.Tokenize(NULL, "\x02");
+		list->m_str5 = StrTok.Tokenize(NULL, "\x02");
+		list->m_str6 = StrTok.Tokenize(NULL, "\x02");
+		if(-1 != list->m_str6.Find("N")){
+			m_unread++;
 		}
+		list->m_str7 = StrTok.Tokenize(NULL, "\x02");
+		list->m_str8 = StrTok.Tokenize(NULL, "\x02");
+		list->m_str9 = StrTok.Tokenize(NULL, "\x02");
+
 		n++;
 		m_array_list.Add(list);
 		tmp.Empty();
@@ -330,7 +301,7 @@ void CSummaryView::SetItem(CString path)
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
 	CMainFrame *mf = (CMainFrame*)this->GetParentFrame();
 	CListCtrl& lc = GetListCtrl();
-	lc.DeleteAllItems();
+	SelectItem(-1);
 	m_path = path; // ݕ\悤ƂĂlistt@ĈtH_̃pXm_pathɕۑ
 	m_unread = 0;
 
@@ -368,7 +339,7 @@ void CSummaryView::AddList(SLISTSTACK *pList)
 {
 	CListCtrl& lc = GetListCtrl();
 	m_stack_num++;
-	m_array_list.Add(*pList);
+	m_array_list.Add(pList);
 	lc.InsertItem(0, pList->m_str1.GetBuffer(0)); // I[i[h[Ȃ̂ŃTuACeOnGetdispinfoŏ
 	if(m_index != -1)
 		m_index++;
@@ -401,11 +372,12 @@ BOOL CSummaryView::OnChildNotify(UINT message, WPARAM wParam, LPARAM lParam, LRE
 			}
 
 			// mainframe̊e{^Lɂ
-			mf->m_button_reply = TRUE;
+/*			mf->m_button_reply = TRUE;
 			mf->m_button_transfer = TRUE;
-			mf->m_button_info = TRUE;
+			mf->m_button_info = TRUE;*/
+			mf->UpdateButton2(TRUE);
 
-			tv->Update(m_path + "\\" + m_array_list[m_stack_num-m_index-1].m_str5);
+			tv->Update(m_path + "\\" + m_array_list[m_stack_num-m_index-1]->m_str5);
 
 			*pLResult = 0;
 		}
@@ -413,62 +385,6 @@ BOOL CSummaryView::OnChildNotify(UINT message, WPARAM wParam, LPARAM lParam, LRE
 	return CListView::OnChildNotify(message, wParam, lParam, pLResult);
 }
 
-void CSummaryView::OnChar(UINT nChar, UINT nRepCnt, UINT nFlags) 
-{
-	int i;
-	CPochyApp *app = (CPochyApp *)AfxGetApp();
-	CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;
-	CFolderView *fv = (CFolderView *)mf->m_pTreeV;
-	CStringArray cstra;
-	CUIntArray ia;
-
-	CString current_account = mf->m_pAcntV->GetCurrentAccountName();
-
-	if(mf->Char(nChar))
-		return;
-
-	switch(nChar){
-	case 'd':
-		if(this->m_index != -1){
-			this->m_status_changed |= this->MarkDStatus(m_index);
-			this->SelectNext();
-		}
-		break;
-	case 'u':
-		if(this->m_index != -1){
-			this->m_status_changed |= UnmarkStatus(m_index);
-			this->SelectNext();
-		}
-		break;
-	case 'x':
-		for(i=this->m_array_list.GetSize()-1; i >= 0; i--){
-			if(this->m_array_list.GetAt(i).m_str6.Find("D") != -1){
-				ia.Add(this->m_stack_num-i-1);
-			}
-		}
-		if(fv->GetSelectedItemKind() != FV_TRASH){
-			this->MoveMail(ia, app->m_app_path+"\\"+current_account+"\\trash", SMRY_COLUMN_FROM);
-		}else{
-			CString null;
-			null.Empty();
-			this->DeleteMail(ia);
-		}
-		break;
-	case '<':
-		this->GetListCtrl().SetItemState(this->m_index, ~(LVIS_SELECTED | LVIS_FOCUSED), LVIS_SELECTED | LVIS_FOCUSED);
-		this->GetListCtrl().SetItemState(0, LVIS_SELECTED | LVIS_FOCUSED, LVIS_SELECTED | LVIS_FOCUSED);
-		this->GetListCtrl().EnsureVisible(0, TRUE);
-		break;
-	case '>':
-		this->GetListCtrl().SetItemState(this->m_index, ~(LVIS_SELECTED | LVIS_FOCUSED), LVIS_SELECTED | LVIS_FOCUSED);
-		this->GetListCtrl().SetItemState(this->m_stack_num-1, LVIS_SELECTED | LVIS_FOCUSED, LVIS_SELECTED | LVIS_FOCUSED);
-		this->GetListCtrl().EnsureVisible(this->m_stack_num-1, TRUE);
-		break;
-	default:
-		break;
-	}
-}
-
 void CSummaryView::UpdateColumn(int flag)
 {
 	CListCtrl& lc = this->GetListCtrl();
@@ -512,7 +428,7 @@ void CSummaryView::UpdateColumn(int flag)
 void CSummaryView::SetStatus(int nItem, CString status)
 {
 	if(this->m_index > -1 && this->m_index < m_stack_num){
-		this->m_array_list[this->m_stack_num-nItem-1].m_str6 = status;
+		this->m_array_list[this->m_stack_num-nItem-1]->m_str6 = status;
 		this->GetListCtrl().RedrawItems(nItem,nItem);
 	}
 }
@@ -520,7 +436,7 @@ void CSummaryView::SetStatus(int nItem, CString status)
 BOOL CSummaryView::ClearStatus(int nItem)
 {
 	CString buf;
-	buf = this->m_array_list.GetAt(this->m_stack_num-nItem-1).m_str6;
+	buf = this->m_array_list.GetAt(this->m_stack_num-nItem-1)->m_str6;
 	if(buf.Left(1)=="N"){
 		SetStatus(nItem, " "+buf.Right(1));
 		return TRUE;
@@ -531,7 +447,7 @@ BOOL CSummaryView::ClearStatus(int nItem)
 BOOL CSummaryView::UnmarkStatus(int nItem)
 {
 	CString buf;
-	buf = this->m_array_list.GetAt(this->m_stack_num-nItem-1).m_str6;
+	buf = this->m_array_list.GetAt(this->m_stack_num-nItem-1)->m_str6;
 	if(buf.Left(1)=="D"){
 		this->SetStatus(nItem, " "+buf.Right(1));
 		return TRUE;
@@ -542,7 +458,7 @@ BOOL CSummaryView::UnmarkStatus(int nItem)
 BOOL CSummaryView::MarkDStatus(int nItem)
 {
 	CString buf;
-	buf = this->m_array_list.GetAt(this->m_stack_num-nItem-1).m_str6;
+	buf = this->m_array_list.GetAt(this->m_stack_num-nItem-1)->m_str6;
 	if(buf.Left(1)!="D"){
 		this->SetStatus(nItem, "D"+buf.Right(1));
 		return TRUE;
@@ -588,8 +504,8 @@ void CSummaryView::DeleteMail(CUIntArray &index_array)
 
 	int i = index_array.GetSize()-1;
 	while(i >= 0){
-		DeleteFile(m_path+"\\"+m_array_list.GetAt(m_stack_num-index_array.GetAt(i)-1).m_str5);
-		if (m_array_list.GetAt(m_stack_num-index_array.GetAt(i)-1).m_str6.Find(_T("N")) != -1)
+		DeleteFile(m_path+"\\"+m_array_list.GetAt(m_stack_num-index_array.GetAt(i)-1)->m_str5);
+		if (m_array_list.GetAt(m_stack_num-index_array.GetAt(i)-1)->m_str6.Find(_T("N")) != -1)
 		{
 			m_unread--;
 		}
@@ -599,7 +515,7 @@ void CSummaryView::DeleteMail(CUIntArray &index_array)
 	}
 
 	// something is changed.
-	this->GetListCtrl().DeleteAllItems();
+	SelectItem(-1);
 	this->m_index = -1;
 	this->GetListCtrl().SetItemCountEx(m_stack_num, LVSICF_NOSCROLL);
 	this->m_status_changed = TRUE;
@@ -628,15 +544,15 @@ void CSummaryView::WriteList()
 	CWaitCursor wait_cursor; // turn cursor into sandglass
 	CString str;
 	for(int i=0;i<this->m_array_list.GetSize();i++){
-		str =           m_array_list.GetAt(i).m_str1;
-		str += "\x02" + m_array_list.GetAt(i).m_str2;
-		str += "\x02" + m_array_list.GetAt(i).m_str3;
-		str += "\x02" + m_array_list.GetAt(i).m_str4;
-		str += "\x02" + m_array_list.GetAt(i).m_str5;
-		str += "\x02" + m_array_list.GetAt(i).m_str6;
-		str += "\x02" + m_array_list.GetAt(i).m_str7;
-		str += "\x02" + m_array_list.GetAt(i).m_str8;
-		str += "\x02" + m_array_list.GetAt(i).m_str9;
+		str =           m_array_list.GetAt(i)->m_str1;
+		str += "\x02" + m_array_list.GetAt(i)->m_str2;
+		str += "\x02" + m_array_list.GetAt(i)->m_str3;
+		str += "\x02" + m_array_list.GetAt(i)->m_str4;
+		str += "\x02" + m_array_list.GetAt(i)->m_str5;
+		str += "\x02" + m_array_list.GetAt(i)->m_str6;
+		str += "\x02" + m_array_list.GetAt(i)->m_str7;
+		str += "\x02" + m_array_list.GetAt(i)->m_str8;
+		str += "\x02" + m_array_list.GetAt(i)->m_str9;
 		str += "\r\n";
 		fwrite(str, sizeof(char),str.GetLength(),file);
 	}
@@ -648,11 +564,8 @@ void CSummaryView::OnDblclk(NMHDR* pNMHDR, LRESULT* pResult)
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
 	CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;
 	CFolderView *fv = (CFolderView*)mf->m_pTreeV;
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
 	CString box_name;
 	CString current_account = mf->m_pAcntV->GetCurrentAccountName();
-// end
 
 	POSITION Pos = this->GetListCtrl().GetFirstSelectedItemPosition();
 	int index = (int)Pos-1;
@@ -662,7 +575,7 @@ void CSummaryView::OnDblclk(NMHDR* pNMHDR, LRESULT* pResult)
 		index != -1)
 	{
 		CMimeDecode md;
-		if(!md.DoIt(m_path + "\\" + this->m_array_list[m_stack_num-index-1].m_str5)){
+		if(!md.DoIt(m_path + "\\" + this->m_array_list[m_stack_num-index-1]->m_str5)){
 			return;
 		}
 
@@ -689,7 +602,38 @@ void CSummaryView::OnDblclk(NMHDR* pNMHDR, LRESULT* pResult)
 			data.m_content_disposition = md.GetRawCD(i);
 			md.GetBody(i, body);
 			g_cstra2cstr(body, data.m_body, g_cstra_getsize(body));
-			data.m_encoding_type = md.GetEncodingType(i);
+//			data.m_encoding_type = md.GetEncodingType(i);
+/*
+				m_enc = SEVEN_BIT;
+			if(g_cstr_compare(cte.GetBuffer(0), "8bit"))
+				m_enc = EIGHT_BIT;
+			if(g_cstr_compare(cte.GetBuffer(0), "bin"))
+				m_enc = BIN;
+			if(g_cstr_compare(cte.GetBuffer(0), "base64"))
+				m_enc = BASE64;
+			if(g_cstr_compare(cte.GetBuffer(0), "x-gzip64")) // x-gzip64 is temporarily treat as base64 (zlib.dll is necessary)
+				m_enc = BASE64;
+			if(g_cstr_compare(cte.GetBuffer(0), "quoted-printable"))
+				m_enc = QUOTED_PRINTABLE;
+				*/
+
+			switch(md.GetEncodingType(i)){
+			case SEVEN_BIT:
+				data.m_encoding_type = "7bit";
+				break;
+			case EIGHT_BIT:
+				data.m_encoding_type = "8bit";
+				break;
+			case BIN:
+				data.m_encoding_type = "bin";
+				break;
+			case BASE64:
+				data.m_encoding_type = "base64";
+				break;
+			case QUOTED_PRINTABLE:
+				data.m_encoding_type = "quoted-printable";
+				break;
+			}
 			data.m_file_name = md.GetFileName(i);
 			data.m_type = md.GetContentType(i);
 			app->m_me.AddMultipart(data);
@@ -698,9 +642,6 @@ void CSummaryView::OnDblclk(NMHDR* pNMHDR, LRESULT* pResult)
 		if(fv->GetSelectedItemKind() == FV_DRAFT){
 			CUIntArray ia;
 			this->GetSelectedMail(ia);
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
-//			CString message = this->m_array_list[this->m_stack_num-this->m_index-1].m_str2+"\r\n\r\ndraft폜Ă悢łH";
 			CString message;
 			GetPrivateProfileString(
 				"mailbox",
@@ -712,16 +653,16 @@ void CSummaryView::OnDblclk(NMHDR* pNMHDR, LRESULT* pResult)
 			box_name.ReleaseBuffer();
 			if(box_name.IsEmpty()){
 				message.Format("%s\r\n\r\n%s폜Ă悢łH",
-					this->m_array_list[this->m_stack_num-this->m_index-1].m_str2,
+					this->m_array_list[this->m_stack_num-this->m_index-1]->m_str2,
 					DEF_BOXNAME_DRAFT);
 			}else{
 				message.Format("%s\r\n\r\n%s폜Ă悢łH",
-					this->m_array_list[this->m_stack_num-this->m_index-1].m_str2,
+					this->m_array_list[this->m_stack_num-this->m_index-1]->m_str2,
 					box_name);
 			}
-// end
 			if(IDYES == AfxMessageBox(message, MB_YESNO)){
 				this->DeleteMail(ia);
+				mf->UpdateButton2(FALSE);
 			}
 		}
 		app->CreateDraftFrame(mf->m_pAcntV->GetCurrentAccountName());
@@ -736,10 +677,7 @@ void CSummaryView::OnKeyDown(UINT nChar, UINT nRepCnt, UINT nFlags)
 	CFolderView *fv = (CFolderView *)mf->m_pTreeV;
 	CStringArray cstra;
 	CString message;
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
 	CString box_name;
-// end
 	CUIntArray ia;
 
 	CString current_account = mf->m_pAcntV->GetCurrentAccountName();
@@ -752,9 +690,6 @@ void CSummaryView::OnKeyDown(UINT nChar, UINT nRepCnt, UINT nFlags)
 			}
 			if(fv->GetSelectedItemKind() != FV_TRASH){
 				if(ia.GetSize() == 1){
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
-//					message = this->m_array_list[this->m_stack_num-this->m_index-1].m_str2+"\r\n\r\ntrashɈڂĂ悢łH";
 					GetPrivateProfileString(
 						"mailbox",
 						"trash",
@@ -765,18 +700,14 @@ void CSummaryView::OnKeyDown(UINT nChar, UINT nRepCnt, UINT nFlags)
 					box_name.ReleaseBuffer();
 					if(box_name.IsEmpty()){
 						message.Format("%s\r\n\r\n%sɈڂĂ悢łH",
-							this->m_array_list[this->m_stack_num-this->m_index-1].m_str2,
+							this->m_array_list[this->m_stack_num-this->m_index-1]->m_str2,
 							DEF_BOXNAME_TRASH);
 					}else{
 						message.Format("%s\r\n\r\n%sɈڂĂ悢łH",
-							this->m_array_list[this->m_stack_num-this->m_index-1].m_str2,
+							this->m_array_list[this->m_stack_num-this->m_index-1]->m_str2,
 							box_name);
 					}
-// end
 				}else if(ia.GetSize() > 1){
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
-//					message = "\r\n\r\ntrashɈڂĂ悢łH";
 					GetPrivateProfileString(
 						"mailbox",
 						"trash",
@@ -790,14 +721,13 @@ void CSummaryView::OnKeyDown(UINT nChar, UINT nRepCnt, UINT nFlags)
 					}else{
 						message.Format("\r\n\r\n%sɈڂĂ悢łH", box_name);
 					}
-// end
 				}
 				if(IDYES == AfxMessageBox(message, MB_YESNO)){
 					this->MoveMail(ia, app->m_app_path+"\\"+current_account+"\\trash", SMRY_COLUMN_FROM);
 				}
 			}else{
 				if(ia.GetSize() == 1){
-					message = this->m_array_list[this->m_stack_num-this->m_index-1].m_str2+"\r\n\r\n폜Ă悢łH";
+					message = this->m_array_list[this->m_stack_num-this->m_index-1]->m_str2+"\r\n\r\n폜Ă悢łH";
 				}else if(ia.GetSize() > 1){
 					message = "\r\n\r\n폜Ă悢łH";
 				}
@@ -805,6 +735,8 @@ void CSummaryView::OnKeyDown(UINT nChar, UINT nRepCnt, UINT nFlags)
 					this->DeleteMail(ia);
 				}
 			}
+			// invalidate some button in toolbar.
+			mf->UpdateButton2(FALSE);
 			break;
 		default:
 			break;
@@ -873,8 +805,6 @@ BOOL CSummaryView::SaveMail(CString path, CString mail, int mail_status, int wha
 	CString char_set;
 	int num;
 
-	SLISTSTACK data;
-
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
 	CMainFrame *mf = (CMainFrame *)app->m_pMainWnd;
 
@@ -990,23 +920,25 @@ BOOL CSummaryView::SaveMail(CString path, CString mail, int mail_status, int wha
 	Write2List.WriteString(list);
 	Write2List.Close();
 
-	data.m_str1 = size;
-	data.m_str2 = subject;
+	SLISTSTACK* data = new SLISTSTACK;
+
+	data->m_str1 = size;
+	data->m_str2 = subject;
 	// ۑɂăT}[ɕ\񂪈Ⴄ
 	if(what_kind_box == SMRY_COLUMN_TO)
-		data.m_str3 = to;
+		data->m_str3 = to;
 	else
-		data.m_str3 = from;
-	data.m_str4 = date;
-	data.m_str5 = seq;
-	data.m_str6 = stat;
-	data.m_str7 = message_id;
-	data.m_str8 = in_reply_to;
-	data.m_str9 = char_set;
+		data->m_str3 = from;
+	data->m_str4 = date;
+	data->m_str5 = seq;
+	data->m_str6 = stat;
+	data->m_str7 = message_id;
+	data->m_str8 = in_reply_to;
+	data->m_str9 = char_set;
 
 	// ۑ悪ݕ\ĂtH_Ȃȉs
 	if(m_path == path){
-		AddList(&data);
+		AddList(data);
 		if(m_index != -1){
 			m_index++;
 		}
@@ -1042,8 +974,6 @@ BOOL CSummaryView::SaveMail(CString path, CStringArray &mail, int mail_status, i
 	CString char_set;
 	int num;
 
-	SLISTSTACK data;
-
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
 	CMainFrame *mf = (CMainFrame *)app->m_pMainWnd;
 
@@ -1147,26 +1077,27 @@ BOOL CSummaryView::SaveMail(CString path, CStringArray &mail, int mail_status, i
 	Write2List.WriteString(list);
 	Write2List.Close();
 
-	data.m_str1 = size;
-	data.m_str2 = subject;
+	SLISTSTACK* data = new SLISTSTACK;
+	data->m_str1 = size;
+	data->m_str2 = subject;
 	// content of summaryview is changing up to which folder is selected in folderview.
 	// if outbox is selected, summaryview display [To] address instead of [From].
 	// if other box but outbox is selected, viceversa.
 	if(what_kind_box == SMRY_COLUMN_TO)
-		data.m_str3 = to;
+		data->m_str3 = to;
 	else
-		data.m_str3 = from;
-	data.m_str4 = date;
-	data.m_str5 = seq;
-	data.m_str6 = stat;
-	data.m_str7 = message_id;
-	data.m_str8 = in_reply_to;
-	data.m_str9 = char_set;
+		data->m_str3 = from;
+	data->m_str4 = date;
+	data->m_str5 = seq;
+	data->m_str6 = stat;
+	data->m_str7 = message_id;
+	data->m_str8 = in_reply_to;
+	data->m_str9 = char_set;
 
 	// if saving to current displayed folder, need to increment m_index. 
 	// m_index is variable of current selected item number.
 	if(m_path == path){
-		AddList(&data);
+		AddList(data);
 		if(m_index != -1){
 			m_index++;
 		}
@@ -1183,14 +1114,6 @@ BOOL CSummaryView::SaveMail(CString path, CStringArray &mail, int mail_status, i
 
 BOOL CSummaryView::PreTranslateMessage(MSG* pMsg)
 {
-	if(pMsg->message == WM_KEYDOWN){
-		if(pMsg->wParam == 78){ // pressing [n] is same as [PgDn].
-			pMsg->wParam = 40;
-		}
-		else if(pMsg->wParam == 80){ // pressing [p] is same as [PgUp].
-			pMsg->wParam = 38;
-		}
-	}
 	return CListView::PreTranslateMessage(pMsg);
 }
 
@@ -1264,10 +1187,11 @@ void CSummaryView::OnColumnclick(NMHDR* pNMHDR, LRESULT* pResult)
 	CListCtrl &lc = GetListCtrl();
 
 	m_index = -1;
-	lc.DeleteAllItems();
+	SelectItem(-1);
 	hv->Clear();
 	tv->Clear();
 	mf->HideMultiPartView(TRUE);
+	mf->UpdateButton2(FALSE);
 	lc.SetItemCountEx(m_stack_num, LVSICF_NOSCROLL);
 
 	*pResult = 0;
@@ -1290,16 +1214,16 @@ int CSummaryView::QuickSortPartition(int start, int end, int item_num, int order
 		switch(item_num){
 		case 0:
 			if(order == 1){
-				pivot = m_array_list.GetAt(end).m_str6+m_array_list.GetAt(end).m_str4;
+				pivot = m_array_list.GetAt(end)->m_str6+m_array_list.GetAt(end)->m_str4;
 				for(;;){
 					while(i<j){
-						buf1 = m_array_list.GetAt(i).m_str6+m_array_list.GetAt(i).m_str4;
+						buf1 = m_array_list.GetAt(i)->m_str6+m_array_list.GetAt(i)->m_str4;
 						if(_stricmp(buf1, pivot) < 0)
 							break;
 						i++;
 					}
 					while(i<j){
-						buf2 = m_array_list.GetAt(j).m_str6+m_array_list.GetAt(j).m_str4;
+						buf2 = m_array_list.GetAt(j)->m_str6+m_array_list.GetAt(j)->m_str4;
 						if(_stricmp(buf2, pivot) > 0)
 							break;
 						j--;
@@ -1309,16 +1233,16 @@ int CSummaryView::QuickSortPartition(int start, int end, int item_num, int order
 					this->QuickSortSwapStack(i, j);
 				}
 			}else if(order == 2){
-				pivot = m_array_list.GetAt(end).m_str6+m_array_list.GetAt(end).m_str4;
+				pivot = m_array_list.GetAt(end)->m_str6+m_array_list.GetAt(end)->m_str4;
 				for(;;){
 					while(i<j){
-						buf1 = m_array_list.GetAt(i).m_str6+m_array_list.GetAt(i).m_str4;
+						buf1 = m_array_list.GetAt(i)->m_str6+m_array_list.GetAt(i)->m_str4;
 						if(_stricmp(buf1, pivot) > 0)
 							break;
 						i++;
 					}
 					while(i<j){
-						buf2 = m_array_list.GetAt(j).m_str6+m_array_list.GetAt(j).m_str4;
+						buf2 = m_array_list.GetAt(j)->m_str6+m_array_list.GetAt(j)->m_str4;
 						if(_stricmp(buf2, pivot) < 0)
 							break;
 						j--;
@@ -1331,16 +1255,16 @@ int CSummaryView::QuickSortPartition(int start, int end, int item_num, int order
 			break;
 		case 1:
 			int c;
-			c = atoi(m_array_list.GetAt(end).m_str1);
+			c = atoi(m_array_list.GetAt(end)->m_str1);
 			if(order == 1){
 				for(;;){
 					while(i<j){
-						if(c < atoi(m_array_list.GetAt(i).m_str1))
+						if(c < atoi(m_array_list.GetAt(i)->m_str1))
 							break;
 						i++;
 					}
 					while(i<j){
-						if(c > atoi(m_array_list.GetAt(j).m_str1))
+						if(c > atoi(m_array_list.GetAt(j)->m_str1))
 							break;
 						j--;
 					}
@@ -1351,12 +1275,12 @@ int CSummaryView::QuickSortPartition(int start, int end, int item_num, int order
 			}else if(order == 2){
 				for(;;){
 					while(i<j){
-						if(c > atoi(m_array_list.GetAt(i).m_str1))
+						if(c > atoi(m_array_list.GetAt(i)->m_str1))
 							break;
 						i++;
 					}
 					while(i<j){
-						if(c < atoi(m_array_list.GetAt(j).m_str1))
+						if(c < atoi(m_array_list.GetAt(j)->m_str1))
 							break;
 						j--;
 					}
@@ -1368,16 +1292,16 @@ int CSummaryView::QuickSortPartition(int start, int end, int item_num, int order
 			break;
 		case 2:
 			if(order == 1){
-				pivot = m_array_list.GetAt(end).m_str2+m_array_list.GetAt(end).m_str4;
+				pivot = m_array_list.GetAt(end)->m_str2+m_array_list.GetAt(end)->m_str4;
 				for(;;){
 					while(i<j){
-						buf1 = m_array_list.GetAt(i).m_str2+m_array_list.GetAt(i).m_str4;
+						buf1 = m_array_list.GetAt(i)->m_str2+m_array_list.GetAt(i)->m_str4;
 						if(_stricmp(buf1, pivot) < 0)
 							break;
 						i++;
 					}
 					while(i<j){
-						buf2 = m_array_list.GetAt(j).m_str2+m_array_list.GetAt(j).m_str4;
+						buf2 = m_array_list.GetAt(j)->m_str2+m_array_list.GetAt(j)->m_str4;
 						if(_stricmp(buf2, pivot) > 0)
 							break;
 						j--;
@@ -1387,16 +1311,16 @@ int CSummaryView::QuickSortPartition(int start, int end, int item_num, int order
 					this->QuickSortSwapStack(i, j);
 				}
 			}else if(order == 2){
-				pivot = m_array_list.GetAt(end).m_str2+m_array_list.GetAt(end).m_str4;
+				pivot = m_array_list.GetAt(end)->m_str2+m_array_list.GetAt(end)->m_str4;
 				for(;;){
 					while(i<j){
-						buf1 = m_array_list.GetAt(i).m_str2+m_array_list.GetAt(i).m_str4;
+						buf1 = m_array_list.GetAt(i)->m_str2+m_array_list.GetAt(i)->m_str4;
 						if(_stricmp(buf1, pivot) > 0)
 							break;
 						i++;
 					}
 					while(i<j){
-						buf2 = m_array_list.GetAt(j).m_str2+m_array_list.GetAt(j).m_str4;
+						buf2 = m_array_list.GetAt(j)->m_str2+m_array_list.GetAt(j)->m_str4;
 						if(_stricmp(buf2, pivot) < 0)
 							break;
 						j--;
@@ -1409,16 +1333,16 @@ int CSummaryView::QuickSortPartition(int start, int end, int item_num, int order
 			break;
 		case 3:
 			if(order == 1){
-				pivot = m_array_list.GetAt(end).m_str3+m_array_list.GetAt(end).m_str4;
+				pivot = m_array_list.GetAt(end)->m_str3+m_array_list.GetAt(end)->m_str4;
 				for(;;){
 					while(i<j){
-						buf1 = m_array_list.GetAt(i).m_str3+m_array_list.GetAt(i).m_str4;
+						buf1 = m_array_list.GetAt(i)->m_str3+m_array_list.GetAt(i)->m_str4;
 						if(_stricmp(buf1, pivot) < 0)
 							break;
 						i++;
 					}
 					while(i<j){
-						buf2 = m_array_list.GetAt(j).m_str3+m_array_list.GetAt(j).m_str4;
+						buf2 = m_array_list.GetAt(j)->m_str3+m_array_list.GetAt(j)->m_str4;
 						if(_stricmp(buf2, pivot) > 0)
 							break;
 						j--;
@@ -1428,16 +1352,16 @@ int CSummaryView::QuickSortPartition(int start, int end, int item_num, int order
 					this->QuickSortSwapStack(i, j);
 				}
 			}else if(order == 2){
-				pivot = m_array_list.GetAt(end).m_str3+m_array_list.GetAt(end).m_str4;
+				pivot = m_array_list.GetAt(end)->m_str3+m_array_list.GetAt(end)->m_str4;
 				for(;;){
 					while(i<j){
-						buf1 = m_array_list.GetAt(i).m_str3+m_array_list.GetAt(i).m_str4;
+						buf1 = m_array_list.GetAt(i)->m_str3+m_array_list.GetAt(i)->m_str4;
 						if(_stricmp(buf1, pivot) > 0)
 							break;
 						i++;
 					}
 					while(i<j){
-						buf2 = m_array_list.GetAt(j).m_str3+m_array_list.GetAt(j).m_str4;
+						buf2 = m_array_list.GetAt(j)->m_str3+m_array_list.GetAt(j)->m_str4;
 						if(_stricmp(buf2, pivot) < 0)
 							break;
 						j--;
@@ -1450,16 +1374,16 @@ int CSummaryView::QuickSortPartition(int start, int end, int item_num, int order
 			break;
 		case 4:
 			if(order == 1){
-				pivot = m_array_list.GetAt(end).m_str4;
+				pivot = m_array_list.GetAt(end)->m_str4;
 				for(;;){
 					while(i<j){
-						buf1 = m_array_list.GetAt(i).m_str4;
+						buf1 = m_array_list.GetAt(i)->m_str4;
 						if(_stricmp(buf1, pivot) < 0)
 							break;
 						i++;
 					}
 					while(i<j){
-						buf2 = m_array_list.GetAt(j).m_str4;
+						buf2 = m_array_list.GetAt(j)->m_str4;
 						if(_stricmp(buf2, pivot) > 0)
 							break;
 						j--;
@@ -1469,16 +1393,16 @@ int CSummaryView::QuickSortPartition(int start, int end, int item_num, int order
 					this->QuickSortSwapStack(i, j);
 				}
 			}else if(order == 2){
-				pivot = m_array_list.GetAt(end).m_str4;
+				pivot = m_array_list.GetAt(end)->m_str4;
 				for(;;){
 					while(i<j){
-						buf1 = m_array_list.GetAt(i).m_str4;
+						buf1 = m_array_list.GetAt(i)->m_str4;
 						if(_stricmp(buf1, pivot) > 0)
 							break;
 						i++;
 					}
 					while(i<j){
-						buf2 = m_array_list.GetAt(j).m_str4;
+						buf2 = m_array_list.GetAt(j)->m_str4;
 						if(_stricmp(buf2, pivot) < 0)
 							break;
 						j--;
@@ -1492,15 +1416,15 @@ int CSummaryView::QuickSortPartition(int start, int end, int item_num, int order
 		}
 	}else if(order == 0){
 		int c;
-		c = atoi(m_array_list.GetAt(end).m_str5);
+		c = atoi(m_array_list.GetAt(end)->m_str5);
 		for(;;){
 			while(i<j){
-				if(c < atoi(m_array_list.GetAt(i).m_str5))
+				if(c < atoi(m_array_list.GetAt(i)->m_str5))
 					break;
 				i++;
 			}
 			while(i<j){
-				if(c > atoi(m_array_list.GetAt(j).m_str5))
+				if(c > atoi(m_array_list.GetAt(j)->m_str5))
 					break;
 				j--;
 			}
@@ -1517,23 +1441,9 @@ int CSummaryView::QuickSortPartition(int start, int end, int item_num, int order
 // swap all member of SLISTSTACK one another.
 void CSummaryView::QuickSortSwapStack(int i, int j)
 {
-	SLISTSTACK tmp;
-
-	tmp.m_str1 = m_array_list.GetAt(i).m_str1;
-	tmp.m_str2 = m_array_list.GetAt(i).m_str2;
-	tmp.m_str3 = m_array_list.GetAt(i).m_str3;
-	tmp.m_str4 = m_array_list.GetAt(i).m_str4;
-	tmp.m_str5 = m_array_list.GetAt(i).m_str5;
-	tmp.m_str6 = m_array_list.GetAt(i).m_str6;
-	tmp.m_str7 = m_array_list.GetAt(i).m_str7;
-	tmp.m_str8 = m_array_list.GetAt(i).m_str8;
-	tmp.m_str9 = m_array_list.GetAt(i).m_str9;
-	tmp.m_str10 = m_array_list.GetAt(i).m_str10;
-	tmp.m_str11 = m_array_list.GetAt(i).m_str11;
-	tmp.m_str12 = m_array_list.GetAt(i).m_str12;
-
-	m_array_list.SetAt(i, m_array_list.GetAt(j));
-	m_array_list.SetAt(j, tmp);
+	SLISTSTACK* pTemp = m_array_list[i];
+	m_array_list[i] = m_array_list[j];
+	m_array_list[j] = pTemp;
 }
 
 // entry function of quick sort.
@@ -1592,11 +1502,12 @@ void CSummaryView::SetColumnOrderStatus(int status)
 
 void CSummaryView::ReBuildSummary(CString path, int mode)
 {
+	CPochyApp *app = (CPochyApp *)AfxGetApp();
+	CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;
 	CFileFind ff;
 	BOOL b;
 	CHeaderInfo hi;
 	CStringArray header;
-	SLISTSTACK data;
 
 	m_array_list.RemoveAll();
 	m_stack_num = 0;
@@ -1650,19 +1561,20 @@ void CSummaryView::ReBuildSummary(CString path, int mode)
 			else
 				stat = "NM";
 
-			data.m_str1 = size;
-			data.m_str2 = subject;
+			SLISTSTACK* data = new SLISTSTACK;
+			data->m_str1 = size;
+			data->m_str2 = subject;
 			// ۑɂăT}[ɕ\񂪈Ⴄ
 			if(mode == SMRY_COLUMN_TO)
-				data.m_str3 = to;
+				data->m_str3 = to;
 			else
-				data.m_str3 = from;
-			data.m_str4 = date;
-			data.m_str5 = ff.GetFileName();
-			data.m_str6 = stat;
-			data.m_str7 = message_id;
-			data.m_str8 = in_reply_to;
-			data.m_str9 = char_set;
+				data->m_str3 = from;
+			data->m_str4 = date;
+			data->m_str5 = ff.GetFileName();
+			data->m_str6 = stat;
+			data->m_str7 = message_id;
+			data->m_str8 = in_reply_to;
+			data->m_str9 = char_set;
 			m_array_list.Add(data);
 			m_stack_num++;
 		}
@@ -1670,6 +1582,9 @@ void CSummaryView::ReBuildSummary(CString path, int mode)
 	this->QuickSort(0, m_array_list.GetSize()-1, NULL, 0);
 	this->SetItem(path);
 	RedrawUnreadCount();
+
+	// invaidate some button in toolbar
+	mf->UpdateButton2(FALSE);
 }
 
 void CSummaryView::OnLButtonUp(UINT nFlags, CPoint point) 
@@ -1725,7 +1640,7 @@ void CSummaryView::OnPopupDel()
 	this->GetSelectedMail(ia);
 	if(fv->GetSelectedItemKind() != FV_TRASH){
 		if(ia.GetSize() == 1){
-			message = this->m_array_list[this->m_stack_num-this->m_index-1].m_str2+"\r\n\r\ntrashɈڂĂ悢łH";
+			message = this->m_array_list[this->m_stack_num-this->m_index-1]->m_str2+"\r\n\r\ntrashɈڂĂ悢łH";
 		}else if(ia.GetSize() > 1){
 			message = "\r\n\r\ntrashɈڂĂ悢łH";
 		}
@@ -1735,7 +1650,7 @@ void CSummaryView::OnPopupDel()
 		this->MoveMail(ia, app->m_app_path+"\\"+current_account+"\\trash", SMRY_COLUMN_FROM);
 	}else{
 		if(ia.GetSize() == 1){
-			message = this->m_array_list[this->m_stack_num-this->m_index-1].m_str2+"\r\n\r\n폜Ă悢łH";
+			message = this->m_array_list[this->m_stack_num-this->m_index-1]->m_str2+"\r\n\r\n폜Ă悢łH";
 		}else if(ia.GetSize() > 1){
 			message = "\r\n\r\n폜Ă悢łH";
 		}
@@ -1744,6 +1659,8 @@ void CSummaryView::OnPopupDel()
 		}		
 		this->DeleteMail(ia);
 	}
+	// imvalidate some button in toolbar
+	mf->UpdateButton2(FALSE);
 }
 
 void CSummaryView::OnPopupHeaderInfo() 
@@ -1796,7 +1713,28 @@ void CSummaryView::OnPopupRawmailInfo()
 void CSummaryView::OnPopupRebuild() 
 {
 	CWaitCursor wait_cursor; // turn cursor into sandglass
-	this->ReBuildSummary(this->m_path, SMRY_COLUMN_FROM);
+	CPochyApp *app = (CPochyApp *)AfxGetApp();
+	CMainFrame *mf = (CMainFrame *)app->m_pMainWnd;
+	CFolderView *fv = (CFolderView *)mf->m_pTreeV;
+
+	int mode;
+	switch(fv->GetCurrentItemKind()){
+	case FV_INBOX:
+	case FV_TRASH:
+	case FV_TOP:
+	case FV_OTHER:
+		mode = SMRY_COLUMN_FROM;
+		break;
+	case FV_OUTBOX:
+	case FV_DRAFT:
+		mode = SMRY_COLUMN_TO;
+		break;
+	default:
+		break;
+	}
+
+	this->ReBuildSummary(this->m_path, mode);
+	mf->UpdateButton2(FALSE);
 }
 
 void CSummaryView::ClearAllMail(CString path)
@@ -1842,7 +1780,7 @@ void CSummaryView::MoveMail(CUIntArray &index_array, CString to, int what_kind_b
 	int i=0;
 	while(i < index_array.GetSize()){
 		cstra.RemoveAll();
-		g_file2cstra(this->m_path+"\\"+this->m_array_list.GetAt(this->m_stack_num-index_array.GetAt(i)-1).m_str5, cstra);
+		g_file2cstra(this->m_path+"\\"+this->m_array_list.GetAt(this->m_stack_num-index_array.GetAt(i)-1)->m_str5, cstra);
 		this->SaveMail(to, cstra, SMRY_STATUS_NONE, what_kind_box);
 		i++;
 	}
@@ -1859,7 +1797,7 @@ void CSummaryView::Clear()
 	CListCtrl& lc = GetListCtrl();
 
 	// delete all item;	
-	lc.DeleteAllItems();
+	SelectItem(-1);
 	this->m_array_list.RemoveAll();
 	this->m_stack_num = 0;
 	this->m_path.Empty();
@@ -2342,18 +2280,12 @@ void CSummaryView::WriteIniColumnOrder()
 // ǐ folder.ini ɕۑ
 void CSummaryView::SaveUnreadCount(const CString& strPath, const int nUnread, const int /*nStack*/)
 {
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
-//	CString strBuffer;
-//	strBuffer.Format(_T("%d"), nUnread);
-//	::WritePrivateProfileString(_T("list"), _T("UnreadCount"), strBuffer, strPath + _T("\\folder.ini"));
 	if (strPath != _T(""))
 	{
 		CString strBuffer;
 		strBuffer.Format(_T("%d"), nUnread);
 		::WritePrivateProfileString(_T("list"), _T("UnreadCount"), strBuffer, strPath + _T("\\folder.ini"));
 	}
-// end
 }
 
 // ǐ folder.ini 擾
@@ -2421,3 +2353,188 @@ void CSummaryView::RedrawUnreadCount()
 		pFolderView->UpdateWindow();
 	}
 }
+
+BOOL CSummaryView::OnCommand(WPARAM wParam, LPARAM lParam) 
+{
+	switch (LOWORD(wParam))
+	{
+	case ID_CHECK_DELETE_MARK:
+		{
+			if(this->m_index != -1){
+				this->m_status_changed |= this->MarkDStatus(m_index);
+				this->SelectNext();
+			}
+			return TRUE;
+		}
+		break;
+
+	case ID_UNCHECK_DELETE_MARK:
+		{
+			if(this->m_index != -1){
+				this->m_status_changed |= UnmarkStatus(m_index);
+				this->SelectNext();
+			}
+			return TRUE;
+		}
+		break;
+
+	case ID_EXECUTE_DELETE_MARK:
+		{
+			int i;
+			CUIntArray ia;
+			CPochyApp *app = (CPochyApp *)AfxGetApp();
+			CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;
+			CFolderView *fv = (CFolderView *)mf->m_pTreeV;
+			CString current_account = mf->m_pAcntV->GetCurrentAccountName();
+			for(i=this->m_array_list.GetSize()-1; i >= 0; i--){
+				if(this->m_array_list.GetAt(i)->m_str6.Find("D") != -1){
+					ia.Add(this->m_stack_num-i-1);
+				}
+			}
+			if(fv->GetSelectedItemKind() != FV_TRASH){
+				this->MoveMail(ia, app->m_app_path+"\\"+current_account+"\\trash", SMRY_COLUMN_FROM);
+			}else{
+				CString null;
+				null.Empty();
+				this->DeleteMail(ia);
+			}
+			return TRUE;
+		}
+		break;
+
+	case ID_SELECT_TOP_MAIL:
+		{
+			SelectItem(0);
+			return TRUE;
+		}
+		break;
+
+	case ID_SELECT_BOTTOM_MAIL:
+		{
+			SelectItem(m_stack_num - 1);
+			return TRUE;
+		}
+		break;
+	}
+	
+	return CBitmapListView::OnCommand(wParam, lParam);
+}
+
+void CSummaryView::OnNextMail()
+{
+	CListCtrl& listCtrl = GetListCtrl();
+	if (m_stack_num > 0)
+	{
+		int nNextMail = m_index;
+		if (m_index >= 0 && m_index < m_stack_num - 1)
+		{
+			nNextMail++;
+		}
+		else
+		{
+			nNextMail = 0;
+		}
+
+		if (m_index != nNextMail)
+		{
+			SelectItem(nNextMail);
+		}
+	}
+}
+
+void CSummaryView::OnPrevMail()
+{
+	CListCtrl& listCtrl = GetListCtrl();
+	if (m_stack_num > 0)
+	{
+		int nPrevMail = m_index;
+		if (m_index > 0 && m_index < m_stack_num)
+		{
+			nPrevMail--;
+		}
+		else
+		{
+			nPrevMail = m_stack_num - 1;
+		}
+
+		if (m_index != nPrevMail)
+		{
+			SelectItem(nPrevMail);
+		}
+	}
+}
+
+void CSummaryView::OnNextUnreadMail()
+{
+	SelectNextUnreadMail();
+}
+
+void CSummaryView::SelectItem(const int &nSelect)
+{
+	if(-1 <= nSelect && nSelect < m_stack_num)
+	{
+		// ׂĂ̑I
+		CListCtrl& listCtrl = GetListCtrl();
+		POSITION pos = listCtrl.GetFirstSelectedItemPosition();
+		if (pos != NULL)
+		{
+			while (pos)
+			{
+				int nItem = listCtrl.GetNextSelectedItem(pos);
+				GetListCtrl().SetItemState(nItem, ~(LVIS_SELECTED | LVIS_FOCUSED), LVIS_SELECTED | LVIS_FOCUSED);
+			}
+		}
+
+		if (nSelect >= 0)
+		{
+			// select
+			GetListCtrl().SetItemState(nSelect, LVIS_SELECTED | LVIS_FOCUSED, LVIS_SELECTED | LVIS_FOCUSED);
+			GetListCtrl().EnsureVisible(nSelect, TRUE);
+		}
+	}
+}
+
+void CSummaryView::SelectNextUnreadMail()
+{
+	CPochyApp* pApp = (CPochyApp*)::AfxGetApp();
+	CMainFrame* pMainFrame = (CMainFrame*)pApp->m_pMainWnd;
+
+	if (m_unread <= 0)
+	{
+		pMainFrame->SelectNextUnreadFolder();
+	}
+
+	if (m_unread > 0 && m_stack_num > 0)
+	{
+		int nIndex = m_index;
+		if (m_index < 0 || m_index >= m_stack_num)
+		{
+			nIndex = 0;
+		}
+
+		int i;
+		for (i = nIndex; i < m_stack_num; i++)
+		{
+			CString strFlag = m_array_list.GetAt(m_stack_num - i - 1)->m_str6;
+			if (strFlag.Left(1) == _T('N'))
+			{
+				SelectItem(i);
+				return;
+			}
+		}
+
+		for (i = 0; i < nIndex; i++)
+		{
+			CString strFlag = m_array_list.GetAt(m_stack_num - i - 1)->m_str6;
+			if (strFlag.Left(1) == _T('N'))
+			{
+				SelectItem(i);
+				return;
+			}
+		}
+	}
+	else
+	{
+		::MessageBeep(-1);
+	}
+}
