@@ -31,6 +31,7 @@ static char THIS_FILE[] = __FILE__;
 #endif
 
 #define TEXTVIEW_BACKGROUND_FILENAME _T("\\skin\\TextViewBk.bmp")
+static const int SCROLL_LINE_MARGIN = 2;
 
 /////////////////////////////////////////////////////////////////////////////
 // CTextView
@@ -49,12 +50,14 @@ CTextView::~CTextView()
 
 BEGIN_MESSAGE_MAP(CTextView, CBitmapRichEditView)
 	//{{AFX_MSG_MAP(CTextView)
-	ON_WM_CHAR()
 	ON_WM_RBUTTONDOWN()
 	ON_COMMAND(ID_TEXTVIEW_COPY, OnPopupCopy)
 	ON_COMMAND(ID_TEXTVIEW_SELALL, OnPopupSelall)
 	ON_COMMAND(ID_TEXTVIEW_BROWSER, OnPopupBrowser)
 	ON_COMMAND(ID_TEXTVIEW_EDITOR, OnPopupEditor)
+	ON_COMMAND(ID_PAGE_UP, OnPageUp)
+	ON_COMMAND(ID_PAGE_DOWN, OnPageDown)
+	ON_COMMAND(ID_SCROLL_AND_NEXT_UNREAD, OnScrollAndNextUnread)
 	ON_WM_SETFOCUS()
 	//}}AFX_MSG_MAP
 	ON_NOTIFY_REFLECT_EX(EN_LINK, OnLink)
@@ -204,24 +207,6 @@ void CTextView::Font()
 	TRACE("height=%d\n",cf.yHeight);
 }
 
-void CTextView::OnChar(UINT nChar, UINT nRepCnt, UINT nFlags) 
-{
-	CPochyApp* app = (CPochyApp*)AfxGetApp();
-	CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;
-
-	if(mf->Char(nChar))
-		return;
-
-	switch(nChar){
-		case '<': // plan to implement
-			break;
-		case '>': // plan to implement
-			break;
-		default:
-			break;
-	}
-}
-
 CString CTextView::GetCurrentPath()
 {
 	return m_path;
@@ -297,7 +282,7 @@ BOOL CTextView::IsPgpMime()
 	return g_cstr_compare(m_md.m_hi.GetProtocol(), "application/pgp-encrypted");
 }
 
-void CTextView::OnLink(NMHDR* in_pNotifyHeader, LRESULT* out_pResult)
+BOOL CTextView::OnLink(NMHDR* in_pNotifyHeader, LRESULT* out_pResult)
 {
 	*out_pResult = 0;
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
@@ -305,42 +290,8 @@ void CTextView::OnLink(NMHDR* in_pNotifyHeader, LRESULT* out_pResult)
 	CString current_account = mf->m_pAcntV->GetCurrentAccountName();
 
 	ENLINK * pLink = (ENLINK*)in_pNotifyHeader;
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
-/*	if(pLink->msg == WM_LBUTTONDBLCLK && m_onlink != pLink->lParam){
-		// dNh߂Ɍ݂̃}EX̃NbNꂽ|CgۑĂ
-		m_onlink = pLink->lParam; // ̍
 
-		// get charactor of clicked link
-		GetRichEditCtrl().SetSel(pLink->chrg);
-		CString link = GetRichEditCtrl().GetSelText();
-
-		if(link.Find("mailto:") == 0||link.Find("Mailto:") == 0){
-			// initialization.
-			app->m_me.Initialize();
-			// setting To
-			if(link.Find("?", 7) != -1) // mailto:hoge@hoge.com?subject=PGP%20Key&Body=Please%20send%20keyƂ
-				// subject, body is not implemented.
-				app->m_me.SetTo(link.Mid(7, link.Find("?", 7)-7));
-			else
-				app->m_me.SetTo(link.Mid(7));
-			// setting From
-			CString path = app->m_app_path+"\\"+current_account+"\\account.ini";
-			CString address;
-			GetPrivateProfileString("mailbox", "address", "", address.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
-			address.ReleaseBuffer();
-			app->m_me.SetFrom(address);
-
-			// getting signature.
-			CString signature;
-			g_file2cstring(app->m_app_path+"\\"+current_account+"\\signature", signature);
-			// set main text.
-			app->m_me.AddText(signature);
-			// draftframe
-			app->CreateDraftFrame(mf->m_pAcntV->GetCurrentAccountName());
-		}else{
-			ShellExecute(this->GetSafeHwnd(), _T( "open" ), link, NULL, NULL, SW_NORMAL);*/
-	if(app->GetProfileInt("Customize", "TextViewSingleClick", 1)){
+	if(app->GetProfileInt("Customize", "TextViewSingleClick", 0)){
 		if(pLink->msg == WM_LBUTTONUP && m_onlink != pLink->lParam){
 			// dNh߂Ɍ݂̃}EX̃NbNꂽ|CgۑĂ
 			m_onlink = pLink->lParam; // ̍
@@ -392,7 +343,15 @@ void CTextView::OnLink(NMHDR* in_pNotifyHeader, LRESULT* out_pResult)
 				// draftframe
 				app->CreateDraftFrame(mf->m_pAcntV->GetCurrentAccountName());
 			}else{
-				ShellExecute(this->GetSafeHwnd(), _T( "open" ), link, NULL, NULL, SW_NORMAL);
+				CString strBrowserPath = app->GetProfileString(_T("Customize"), _T("BrowserPath"), _T(""));
+				if (strBrowserPath != _T(""))
+				{
+					::ShellExecute(NULL, NULL, strBrowserPath, link, NULL, SW_NORMAL);
+				}
+				else
+				{
+					ShellExecute(this->GetSafeHwnd(), _T( "open" ), link, NULL, NULL, SW_NORMAL);
+				}
 			}
 		}
 	}else{
@@ -447,11 +406,19 @@ void CTextView::OnLink(NMHDR* in_pNotifyHeader, LRESULT* out_pResult)
 				// draftframe
 				app->CreateDraftFrame(mf->m_pAcntV->GetCurrentAccountName());
 			}else{
-				ShellExecute(this->GetSafeHwnd(), _T( "open" ), link, NULL, NULL, SW_NORMAL);
+				CString strBrowserPath = app->GetProfileString(_T("Customize"), _T("BrowserPath"), _T(""));
+				if (strBrowserPath != _T(""))
+				{
+					::ShellExecute(NULL, NULL, strBrowserPath, link, NULL, SW_NORMAL);
+				}
+				else
+				{
+					ShellExecute(this->GetSafeHwnd(), _T( "open" ), link, NULL, NULL, SW_NORMAL);
+				}
 			}
-// end
 		}
 	}
+	return TRUE;
 }
 
 void CTextView::DisplayPart(int part)
@@ -474,12 +441,12 @@ void CTextView::DisplayPart(int part)
 			message.Remove('\r');
 			message.Remove('\n');
 			char* in_base64 = message.GetBuffer(0);
-			char* out_base64 = new char[message.GetLength()];
+			char* out_base64 = new char[message.GetLength() + 1];
 			int len = from64tobits(out_base64, in_base64, strlen(in_base64));
 			out_base64[len] = 0;
 			message.Empty();
 			message = out_base64;
-			delete out_base64;
+			delete[] out_base64;
 		}
 		// in case of quoted-printable in text/plain or text/html
 		if(m_md.GetEncodingType(part) == QUOTED_PRINTABLE){
@@ -495,7 +462,7 @@ void CTextView::DisplayPart(int part)
 			out_qp[len] = 0;
 			message.Empty();
 			message = out_qp;
-			delete out_qp;
+			delete[] out_qp;
 		}
 		CCodeConvert cc(message);
 		message = cc.ToSjis();
@@ -738,12 +705,12 @@ void CTextView::OnPopupBrowser()
 		buf.Remove('\r');
 		buf.Remove('\n');
 		char* in_base64 = buf.GetBuffer(0);
-		char* out_base64 = new char[buf.GetLength()];
+		char* out_base64 = new char[buf.GetLength() + 1];
 		int len = from64tobits(out_base64, in_base64, strlen(in_base64));
 		out_base64[len] = 0;
 		buf.Empty();
 		buf = out_base64;
-		delete out_base64;
+		delete[] out_base64;
 	}
 	// in case of quoted-printable in text/plain or text/html
 	else if(this->m_md.GetEncodingType(this->m_current_part) == QUOTED_PRINTABLE){
@@ -759,7 +726,7 @@ void CTextView::OnPopupBrowser()
 		out_qp[len] = 0;
 		buf.Empty();
 		buf = out_qp;
-		delete out_qp;
+		delete[] out_qp;
 	}
 
 	CString msg_id;
@@ -772,7 +739,15 @@ void CTextView::OnPopupBrowser()
 		_mkdir(app->m_app_path+"\\temp");
 
 	g_cstring2file(buf, app->m_app_path+"\\temp\\"+msg_id+".html");
-	ShellExecute(NULL, "open", app->m_app_path+"\\temp\\"+msg_id+".html", NULL, NULL, SW_SHOW);
+	CString strBrowserPath = app->GetProfileString(_T("Customize"), _T("BrowserPath"), _T(""));
+	if (strBrowserPath != _T(""))
+	{
+		::ShellExecute(NULL, NULL, strBrowserPath, app->m_app_path+"\\temp\\"+msg_id+".html", NULL, SW_SHOW);
+	}
+	else
+	{
+		ShellExecute(NULL, "open", app->m_app_path+"\\temp\\"+msg_id+".html", NULL, NULL, SW_SHOW);
+	}
 }
 
 void CTextView::OnPopupEditor() 
@@ -845,18 +820,12 @@ void CTextView::SetFontColorAndLink()
 
 	// if header view is not active, set header charactor color.
 	if(!app->GetProfileInt("Customize", "HeaderView", 1)){
-// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
-// start
-//		CString mail;
-//		r.GetWindowText(mail);
-//		r.SetSel(0, mail.Find("\r\n\r\n")+2);
 		FINDTEXTEX ft;
 		ft.chrg.cpMin = 0;
 		ft.chrg.cpMax = -1;
 		ft.lpstrText = _T("\r\r");
 		long pos = r.FindText(FR_DOWN, &ft);
 		r.SetSel(0, pos);
-// end
 		r.GetSelectionCharFormat(cf);
 		cf.dwMask = CFM_COLOR | CFM_BACKCOLOR;
 		cf.crTextColor = RGB(
@@ -900,6 +869,71 @@ void CTextView::Clear()
 
 BOOL CTextView::PreCreateWindow(CREATESTRUCT& cs) 
 {
-
 	return CBitmapRichEditView::PreCreateWindow(cs);
 }
+
+void CTextView::OnPageUp()
+{
+	CRichEditCtrl& richEdit = GetRichEditCtrl();
+
+	int nFirstVisibleLine = richEdit.GetFirstVisibleLine();
+	if (nFirstVisibleLine > 0)
+	{
+		SetFocus();
+		SetRedraw(FALSE);
+		while (richEdit.GetFirstVisibleLine() > 0 &&
+			nFirstVisibleLine < GetLastVisibleLine() - SCROLL_LINE_MARGIN)
+		{
+			richEdit.LineScroll(-1);
+		}
+		SetRedraw(TRUE);
+		Invalidate();
+	}
+}
+
+// page down Ƃ true Ԃ
+bool CTextView::OnPageDown()
+{
+	bool bPageDowned = false;
+
+	CRichEditCtrl& richEdit = GetRichEditCtrl();
+
+	int nLineCount = richEdit.GetLineCount();
+	int nLastVisibleLine = GetLastVisibleLine();
+	if (nLastVisibleLine > 0 && nLastVisibleLine < nLineCount - 1)
+	{
+		SetFocus();
+		int nFirstVisibleLine = richEdit.GetFirstVisibleLine();
+		richEdit.LineScroll(nLastVisibleLine - nFirstVisibleLine - SCROLL_LINE_MARGIN);
+		bPageDowned = true;
+	}
+
+	return bPageDowned;
+}
+
+void CTextView::OnScrollAndNextUnread()
+{
+	if (!OnPageDown())
+	{
+		CPochyApp* pApp = (CPochyApp*)::AfxGetApp();
+		CMainFrame* pMainFrame = (CMainFrame*)pApp->m_pMainWnd;
+		pMainFrame->m_pListV->SelectNextUnreadMail();
+	}
+}
+
+int CTextView::GetLastVisibleLine()
+{
+	int nLastVisibleLine = 0;
+
+	CRect clientRect;
+	GetClientRect(clientRect);
+	if (!clientRect.IsRectEmpty())
+	{
+		CRichEditCtrl& richEdit = GetRichEditCtrl();
+		POINTL point = {clientRect.right, clientRect.bottom};
+		int nLastCharPos = richEdit.SendMessage(EM_CHARFROMPOS, 0, (LPARAM)&point);
+		nLastVisibleLine = richEdit.LineFromChar(nLastCharPos);
+	}
+
+	return nLastVisibleLine;
+}
