@@ -13,6 +13,7 @@
 #include "lib.h"
 #include "_regex.h" // K\֐
 #include "process.h" // getpid()
+#include "base64.h"
 
 void g_log(CString path, CString log)
 {
@@ -293,7 +294,7 @@ void g_cstra2cstr(CStringArray& cstra, CString& cstr, int size)
 
 	char *p = cstr.GetBuffer(size);
 	for(i=0;i<cstra.GetSize();i++){
-		strcpy(p, cstra.GetAt(i).GetBuffer(0));
+		strcpy(p, cstra.GetAt(i));
 		p += cstra.GetAt(i).GetLength();
 	}
 	cstr.ReleaseBuffer();
@@ -677,7 +678,7 @@ void g_strip_part(CString &buf, char *mark)
 }
 
 // ɔpJi܂܂Ă邩ǂm߂
-BOOL g_is_hankana(unsigned char *buf)
+/*BOOL g_is_hankana(unsigned char *buf)
 {
 	unsigned char c = *buf;
 	while(c != NULL){
@@ -688,10 +689,100 @@ BOOL g_is_hankana(unsigned char *buf)
 		c = *(++buf);
 	}
 	return FALSE;
-}
+}*/
 
 int g_richedit_count_char(CString buf)
 {
 	buf.Replace("\r", "");
 	return _mbsnccnt((const unsigned char *)buf.GetBuffer(0), buf.GetLength());
+}
+
+// ̊ȈՕ
+CString g_simple_encode(const CString& in, const TCHAR seed)
+{
+	CString out;
+
+	const int nInLength = in.GetLength();
+	if (nInLength > 0)
+	{
+		TCHAR* tcIn = new TCHAR[nInLength];
+		TCHAR* tcOut = new TCHAR[nInLength * 2 + 10];
+
+		int i;
+		for (i = 0; i < nInLength; i++)
+		{
+			tcIn[i] = TCHAR(in[i] ^ seed);
+		}
+
+		to64frombits((unsigned char*)tcOut, (unsigned char*)tcIn, nInLength);
+
+		out = tcOut;
+
+		delete[] tcOut;
+		delete[] tcIn;
+	}
+
+	return out;
+}
+
+// ̊ȈՕ
+CString g_simple_decode(const CString& in, const TCHAR seed)
+{
+	CString out;
+
+	const int nInLength = in.GetLength();
+	if (nInLength > 0)
+	{
+		TCHAR* tcOut = new TCHAR[nInLength];
+
+		int nOutLength = from64tobits(tcOut, in, nInLength);
+		if (nOutLength > 0)
+		{
+			int i;
+			for (i = 0; i < nOutLength; i++)
+			{
+				tcOut[i] = TCHAR(tcOut[i] ^ seed);
+			}
+			tcOut[i] = _T('\0');
+
+			out = tcOut;
+		}
+
+		delete[] tcOut;
+	}
+
+	return out;
+}
+
+void g_empty_directory(CString path)
+{
+	CFileFind ff;
+	BOOL b = ff.FindFile(path+"\\*.*");
+	if(b){
+		while(b){
+			b = ff.FindNextFile();
+			if(!ff.IsDirectory() && !ff.IsDots()){
+				DeleteFile(path+"\\"+ff.GetFileName());
+			}
+		}
+	}
+}
+
+void g_split_address(CString address, CStringArray *array_address)
+{
+	int pre=0;
+	for(int i=0; i<address.GetLength(); i++){
+		if(address.GetAt(i) == '"'){
+			i++;
+			while(address.GetAt(i) != '"'){
+				i++;
+			}
+			i++;
+		}
+		if(address.GetAt(i) == ','){
+//			array_address->Add(address.Mid(pre, i-pre);
+			pre = i+1;
+		}
+	}
+//	array_address->Add(address.Mid(pre);
 }
\ No newline at end of file
