@@ -48,11 +48,11 @@
 #define DEF_BOXNAME_DRAFT "e"		// default name of draft
 #define DEF_BOXNAME_TRASH "S~"		// default name of trash
 #ifdef _IPV6_
-#define X_MAILER "Pochy 0.1.9 IPv6 ready"	// x-mailer of ipv6 ready version
-#define VERSION "Pochy 0.1.9 IPv6 ready"	// version info of ipv6 ready version
+#define X_MAILER "Pochy 0.2 IPv6 ready"	// x-mailer of ipv6 ready version
+#define VERSION "Pochy 0.2 IPv6 ready"	// version info of ipv6 ready version
 #else
-#define X_MAILER "Pochy 0.1.9"				// x-mailer of normal version
-#define VERSION "Pochy 0.1.9"				// version info of ipv6 ready version
+#define X_MAILER "Pochy 0.2"				// x-mailer of normal version
+#define VERSION "Pochy 0.2"				// version info of ipv6 ready version
 #endif
 #define COPYRIGHT "Copyright (C) 2003 Pochy project team"
 #define CONTRIBUTORS "\
@@ -114,6 +114,10 @@ To: %t\r\n\
 \r\n\
 %M"
 
+#define DEF_DRAFT_TEMPLATE "\r\n\
+\
+%S"
+
 #define get_app CPochyApp* app = (CPochyApp*)AfxGetApp()
 
 /////////////////////////////////////////////////////////////////////////////
