@@ -48,12 +48,12 @@ int fromQPtobits(char *out, char *in, int maxlen)
 
 	do
 	{
-		if(*in == '_'){
+/*		if(*in == '_'){
 			*out = ' ';
 			in++;
 			out++; len++;
 			continue;
-		}
+		}*/
 		if(*in == '='){
 			if(qp_char(*(in+1), *(in+2), (unsigned char *)out) == 0){
 				in += 3;
